var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import s from '../common/locales/strings';
import { TextInputModal } from '../components/modals/TextInputModal';
import { Airship, showError } from '../components/services/AirshipInstance';
import { getLoginKey } from '../keychain';
import { attemptLogin } from '../util/loginAttempt';
import { completeLogin } from './LoginCompleteActions';
/**
 * Logs the user in, using password, PIN, or recovery.
 * There is no error handling in here, since components do that best.
 */
export const login = (attempt, otpKey) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { accountOptions, context } = imports;
    const account = yield attemptLogin(context, attempt, Object.assign(Object.assign({}, accountOptions), { otp: otpKey, // Legacy property name
        otpKey }));
    dispatch(completeLogin(account));
});
export const loginWithTouch = (username) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context, accountOptions } = imports;
    const loginKey = yield getLoginKey(username, `Touch to login user: "${username}"`, s.strings.login_with_password);
    if (loginKey == null)
        return;
    dispatch({ type: 'AUTH_LOGGING_IN_WITH_PIN' });
    const account = yield context.loginWithKey(username, loginKey, accountOptions);
    dispatch(completeLogin(account));
});
export function loginWithPin(username, pin) {
    return (dispatch, getState, imports) => {
        const { context } = imports;
        setTimeout(() => __awaiter(this, void 0, void 0, function* () {
            try {
                const abcAccount = yield context.loginWithPIN(username, pin, imports.accountOptions);
                dispatch(completeLogin(abcAccount));
            }
            catch (e) {
                console.log('LOG IN WITH PIN ERROR ', e);
                if (e.name === 'OtpError') {
                    dispatch({
                        type: 'OTP_ERROR',
                        data: {
                            attempt: { type: 'pin', username, pin },
                            error: e
                        }
                    });
                    return;
                }
                const message = e.name === 'PasswordError'
                    ? s.strings.invalid_pin
                    : e.name === 'UsernameError'
                        ? s.strings.pin_not_enabled
                        : e.name === 'NetworkError'
                            ? `${e.message} ${s.strings.pin_network_error_full_password}`
                            : e.message;
                dispatch({
                    type: 'LOGIN_PIN_FAIL',
                    data: {
                        message,
                        wait: e.wait
                    }
                });
                if (e.wait) {
                    setTimeout(() => {
                        dispatch(processWait(message));
                    }, 1000);
                }
            }
        }), 300);
        // the timeout is a hack until we put in interaction manager.
    };
}
export function processWait(message) {
    return (dispatch, getState, imports) => {
        const state = getState();
        const wait = state.login.wait;
        console.log('RL: wait ', wait);
        if (wait > 0) {
            // console.log('RL: got more than 1', wait)
            dispatch({
                type: 'LOGIN_PIN_FAIL',
                data: {
                    message,
                    wait: wait - 1
                }
            });
            setTimeout(() => {
                dispatch(processWait(message));
            }, 1000);
        }
    };
}
/**
 * Ask the user for the username that goes with a recovery key,
 * then launches the questions scene.
 */
export const launchPasswordRecovery = (recoveryKey) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    function handleSubmit(username) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const questions = yield context.fetchRecovery2Questions(recoveryKey, username);
                dispatch({
                    type: 'START_RECOVERY_LOGIN',
                    data: { recoveryKey, userQuestions: questions, username }
                });
                return true;
            }
            catch (error) {
                showError(error != null && error.name === 'UsernameError'
                    ? s.strings.recovery_by_username_error
                    : error);
                return false;
            }
        });
    }
    Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, onSubmit: handleSubmit, title: s.strings.password_recovery, message: s.strings.recover_by_username, inputLabel: s.strings.username })));
});
