var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { makeReactNativeDisklet } from 'disklet';
import * as React from 'react';
import { NativeModules, Platform } from 'react-native';
import { checkNotifications, openSettings, requestNotifications, RESULTS } from 'react-native-permissions';
import { PermissionsAlertModal } from '../components/modals/PermissionsAlertModal';
import { SecurityAlertsModal } from '../components/modals/SecurityAlertsModal';
import { Airship } from '../components/services/AirshipInstance';
import { getSupportedBiometryType } from '../keychain';
import { launchPasswordRecovery } from './LoginAction';
import { getPreviousUsers } from './PreviousUsersActions';
const { AbcCoreJsUi } = NativeModules;
const disklet = makeReactNativeDisklet();
const permissionsUserFile = 'notificationsPermisions.json';
/**
 * Fires off all the things we need to do to get the login scene up & running.
 */
export const initializeLogin = () => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { customPermissionsFunction } = imports;
    const touchPromise = dispatch(getTouchMode());
    const usersPromise = dispatch(getPreviousUsers());
    dispatch(checkSecurityMessages()).catch(error => console.log(error));
    customPermissionsFunction
        ? customPermissionsFunction()
        : dispatch(checkAndRequestNotifications()).catch(error => console.log(error));
    yield Promise.all([touchPromise, usersPromise]);
    const state = getState();
    // Loading is done, so send the user to the initial route:
    const { previousUsers, touch } = state;
    const { startupUser } = previousUsers;
    const { recoveryKey } = imports;
    if (recoveryKey) {
        dispatch({ type: 'START_LANDING' });
        dispatch(launchPasswordRecovery(recoveryKey));
    }
    else if (startupUser == null) {
        dispatch({ type: 'START_LANDING' });
    }
    else if (startupUser.pinEnabled ||
        (startupUser.touchEnabled && touch !== false)) {
        dispatch({ type: 'START_PIN_LOGIN' });
    }
    else {
        dispatch({ type: 'START_PASSWORD_LOGIN' });
    }
});
const checkSecurityMessages = () => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    const messages = yield context.fetchLoginMessages();
    const relevantMessages = {};
    for (const username of Object.keys(messages)) {
        const message = messages[username];
        // Skip users who haven't fully logged in:
        const info = context.localUsers.find(info => info.username === username);
        if (info == null || !info.keyLoginEnabled)
            continue;
        const { otpResetPending, pendingVouchers = [] } = message;
        if (otpResetPending || pendingVouchers.length > 0) {
            relevantMessages[username] = message;
        }
    }
    if (Object.keys(relevantMessages).length > 0) {
        Airship.show(bridge => (React.createElement(SecurityAlertsModal, { bridge: bridge, messages: relevantMessages, selectUser: username => dispatch({ type: 'AUTH_UPDATE_USERNAME', data: username }) })));
    }
});
const checkAndRequestNotifications = () => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const notificationPermision = yield checkNotifications();
    const notificationStatus = notificationPermision.status;
    const isIos = Platform.OS === 'ios';
    const statusAppRefresh = isIos
        ? yield AbcCoreJsUi.backgroundAppRefreshStatus().catch((error) => console.log(error))
        : undefined;
    const userPermisionStatus = yield disklet
        .getText(permissionsUserFile)
        .catch(error => console.log(error));
    const isNotificationBlocked = userPermisionStatus
        ? JSON.parse(userPermisionStatus).isNotificationBlocked
        : false;
    if ((notificationStatus === RESULTS.BLOCKED ||
        notificationStatus === RESULTS.DENIED ||
        statusAppRefresh === RESULTS.BLOCKED) &&
        !isNotificationBlocked) {
        Airship.show(bridge => React.createElement(PermissionsAlertModal, { bridge: bridge })).then((result) => __awaiter(void 0, void 0, void 0, function* () {
            if (result === 'cancel') {
                return yield disklet.setText(permissionsUserFile, JSON.stringify({ isNotificationBlocked: true }));
            }
            if (result === 'enable' && notificationStatus === RESULTS.DENIED) {
                requestNotifications(isIos ? ['alert', 'badge', 'sound'] : []).catch(error => console.log(error));
            }
            if (result === 'enable' &&
                (notificationStatus === RESULTS.BLOCKED ||
                    statusAppRefresh === RESULTS.BLOCKED)) {
                openSettings().catch(error => console.log(error));
            }
        }));
    }
});
/**
 * Figures out whether or not biometric logins are available.
 */
const getTouchMode = () => (dispatch, getState) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const touch = yield getSupportedBiometryType();
        switch (touch) {
            case 'FaceID':
            case 'TouchID':
                return dispatch({ type: 'SET_TOUCH', data: touch });
            case 'Fingerprint':
                return dispatch({ type: 'SET_TOUCH', data: 'TouchID' });
            default:
                return dispatch({
                    type: 'SET_TOUCH',
                    data: touch ? 'TouchID' : false
                });
        }
    }
    catch (error) {
        console.log(error);
        return dispatch({ type: 'SET_TOUCH', data: false });
    }
});
