var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import Mailer from 'react-native-mail';
import Share from 'react-native-share';
import s from '../common/locales/strings';
import { showError } from '../components/services/AirshipInstance';
import { questionsList } from '../constants/recoveryQuestions';
/**
 * Prepares what is needed for the change recovery scene.
 */
export const initializeChangeRecovery = (account) => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    // Get the user's questions:
    let userQuestions = [];
    const recoveryKey = account.recoveryKey;
    if (recoveryKey != null) {
        try {
            userQuestions = yield context.fetchRecovery2Questions(recoveryKey, account.username);
        }
        catch (error) {
            showError(error);
        }
    }
    dispatch({
        type: 'START_CHANGE_RECOVERY',
        data: { questionsList, userQuestions, account }
    });
});
function truncateUsername(username) {
    return username.slice(0, 2) + '***';
}
export function sendRecoveryEmail(emailAddress, username, recoveryKey) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = s.strings.otp_email_body +
            truncateUsername(username) +
            '<br><br>' +
            'iOS <br>edge://recovery?token=' +
            recoveryKey +
            '<br><br>' +
            'Android https://recovery.edgesecure.co/recovery?token=' +
            recoveryKey +
            '<br><br>' +
            s.strings.otp_email_body2 +
            '<br><br>' +
            s.strings.recovery_token +
            `: ${recoveryKey}` +
            '<br><br>' +
            s.strings.otp_email_body3;
        return yield new Promise((resolve, reject) => Mailer.mail({
            subject: s.strings.otp_email_subject,
            recipients: [emailAddress],
            body: body,
            isHTML: true
        }, (error, event) => {
            if (error != null)
                reject(error);
            if (event === 'sent')
                resolve();
        }));
    });
}
export function shareRecovery(username, recoveryKey) {
    return __awaiter(this, void 0, void 0, function* () {
        const body = s.strings.otp_email_body +
            '\n' +
            truncateUsername(username) +
            '\n iOS: edge://recovery?token=' +
            recoveryKey +
            '\n Android: https://recovery.edgesecure.co/recovery?token=' +
            recoveryKey +
            '\n' +
            s.strings.otp_email_body2 +
            '\n' +
            s.strings.recovery_token +
            `: ${recoveryKey}` +
            '\n' +
            s.strings.otp_email_body3;
        yield Share.open({ title: s.strings.otp_email_subject, message: body }).catch(error => {
            if (!/User did not/.test(error === null || error === void 0 ? void 0 : error.message))
                throw error;
        });
    });
}
