var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { asArray, asJSON, asObject, asString } from 'cleaners';
import { makeReactNativeDisklet } from 'disklet';
import { loadFingerprintFile, supportsTouchId } from '../keychain';
const disklet = makeReactNativeDisklet();
/**
 * Load the user list from core & disk into redux.
 */
export const getPreviousUsers = () => (dispatch, getState, imports) => __awaiter(void 0, void 0, void 0, function* () {
    const { context } = imports;
    // Load disk information:
    const lastUsernames = yield getRecentUsers();
    const fingerprintFile = yield loadFingerprintFile();
    const touchSupported = yield supportsTouchId();
    // Figure out which users have biometric logins:
    const coreUsers = [];
    for (const userInfo of context.localUsers) {
        const { username, pinLoginEnabled, keyLoginEnabled = true } = userInfo;
        const touchEnabled = keyLoginEnabled &&
            touchSupported &&
            fingerprintFile.enabledUsers.includes(username);
        coreUsers.push({ username, pinEnabled: pinLoginEnabled, touchEnabled });
    }
    // Move the top three users to their own list:
    const topUsers = [];
    for (const username of lastUsernames.slice(0, 3)) {
        for (let i = 0; i < coreUsers.length; ++i) {
            if (coreUsers[i].username === username) {
                topUsers.push(coreUsers[i]);
                coreUsers.splice(i, 1);
                break;
            }
        }
    }
    const userList = [...topUsers, ...sortUsers(coreUsers)];
    // Try to find the user requested by the LoginScene props:
    const requestedUser = userList.find(user => user.username === imports.username);
    // Dispatch to redux:
    const data = {
        loaded: true,
        startupUser: requestedUser != null ? requestedUser : userList[0],
        userList,
        usernameOnlyList: userList.map(userInfo => userInfo.username)
    };
    dispatch({ type: 'SET_PREVIOUS_USERS', data });
});
export const setMostRecentUsers = (username) => __awaiter(void 0, void 0, void 0, function* () {
    const lastUsers = yield getRecentUsers();
    const filteredLastUsers = lastUsers.filter((lastUser) => lastUser !== username);
    return disklet.setText('lastusers.json', JSON.stringify([username, ...filteredLastUsers]));
});
function getRecentUsers() {
    return __awaiter(this, void 0, void 0, function* () {
        // Load the last users array:
        try {
            const lastUsernames = yield disklet
                .getText('lastusers.json')
                .then(asLastUsersFile);
            return lastUsernames;
        }
        catch (e) { }
        // Fall back on the older file:
        return yield disklet
            .getText('lastuser.json')
            .then(asLastUsernameFile)
            .then(file => [file.username])
            .catch(() => []);
    });
}
function sortUsers(users) {
    return users.sort((a, b) => {
        const stringA = a.username.toUpperCase();
        const stringB = b.username.toUpperCase();
        if (stringA < stringB) {
            return -1;
        }
        if (stringA > stringB) {
            return 1;
        }
        return 0;
    });
}
const asLastUsersFile = asJSON(asArray(asString));
const asLastUsernameFile = asJSON(asObject({
    username: asString
}));
