import * as React from 'react';
import { ActivityIndicator, Text, TextInput, TouchableWithoutFeedback, View } from 'react-native';
import { validatePin } from '../../actions/CreateAccountActions';
import * as Colors from '../../constants/Colors';
import { scale } from '../../util/scaling';
import { connect } from '../services/ReduxStore';
const MAX_PIN_LENGTH = 4;
class FourDigitInputComponent extends React.Component {
    constructor() {
        super(...arguments);
        this.inputRef = React.createRef();
        this.renderTextInput = () => {
            if (this.props.wait < 1) {
                return (React.createElement(TextInput, { testID: this.props.testID, ref: this.inputRef, style: styles.input, onChangeText: this.handleUpdate, maxLength: MAX_PIN_LENGTH, keyboardType: "number-pad", value: this.props.pin, autoFocus: true }));
            }
            return null;
        };
        this.handleRefocus = () => {
            if (this.inputRef.current != null) {
                this.inputRef.current.blur();
                this.inputRef.current.focus();
            }
        };
        this.handleUpdate = (pin) => {
            // Change pin only when input are numbers
            if (/^\d+$/.test(pin) || pin.length === 0) {
                this.props.onChangeText(pin);
            }
        };
    }
    render() {
        return (React.createElement(TouchableWithoutFeedback, { onPress: this.handleRefocus },
            React.createElement(View, { style: styles.container },
                React.createElement(View, { style: styles.interactiveContainer }, this.renderDotContainer()),
                React.createElement(View, { style: styles.errorContainer },
                    React.createElement(Text, { style: styles.errorText, numberOfLines: 2 }, this.props.error)),
                this.renderTextInput())));
    }
    renderDotContainer() {
        const pinLength = this.props.pin ? this.props.pin.length : 0;
        if (this.props.wait > 0) {
            return React.createElement(ActivityIndicator, { color: Colors.ACCENT_MINT, size: "large" });
        }
        return (React.createElement(View, { style: styles.dotContainer },
            React.createElement(View, { style: [styles.circle, pinLength > 0 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pinLength > 1 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pinLength > 2 && styles.circleSected] }),
            React.createElement(View, { style: [styles.circle, pinLength > 3 && styles.circleSected] })));
    }
}
const styles = {
    // for new account PIN
    container: {
        paddingTop: scale(36),
        width: scale(200),
        height: scale(120)
    },
    interactiveContainer: {
        height: scale(40),
        width: '100%',
        alignItems: 'center'
    },
    errorContainer: {
        width: '100%',
        height: scale(40),
        alignItems: 'center',
        justifyContent: 'center'
    },
    dotContainer: {
        height: '100%',
        width: '100%',
        flexDirection: 'row',
        justifyContent: 'space-between'
    },
    errorText: {
        width: '100%',
        textAlign: 'center',
        color: Colors.ACCENT_RED,
        fontSize: scale(14),
        paddingTop: scale(15)
    },
    input: {
        position: 'absolute',
        top: 0,
        left: 0,
        width: 0,
        height: 0,
        opacity: 0
    },
    circle: {
        borderWidth: scale(2),
        borderColor: Colors.PRIMARY,
        borderRadius: scale(15),
        height: scale(30),
        width: scale(30)
    },
    circleSected: {
        backgroundColor: Colors.SECONDARY,
        borderWidth: scale(2),
        borderColor: Colors.PRIMARY,
        borderRadius: scale(15),
        height: scale(30),
        width: scale(30)
    }
};
export const FourDigitInput = connect((state) => ({
    error: state.create.pinErrorMessage || '',
    pin: state.create.pin,
    username: state.login.username,
    wait: 0
}), (dispatch) => ({
    onChangeText(pin) {
        dispatch(validatePin(pin));
    }
}))(FourDigitInputComponent);
