import * as React from 'react';
import { showError } from '../services/AirshipInstance';
import { MainButton } from '../themed/MainButton';
import { ModalCloseArrow } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
import { MessageText, TitleText } from '../themed/ThemedText';
/**
 * A modal with a title, message, and buttons.
 * This is an alternative to the native `Alert` component.
 *
 * Child components appear between the message and the buttons,
 * but this feature is only meant for inserting extra message elements,
 * like images or custom text formatting.
 *
 * Build a custom modal component if you need form fields, check boxes,
 * or other interactive elements.
 */
export function ButtonsModal(props) {
    const { bridge, buttons, children, closeArrow = false, message, title } = props;
    const handleCancel = () => bridge.resolve(undefined);
    return (React.createElement(ThemedModal, { bridge: bridge, paddingRem: 1, onCancel: handleCancel },
        title != null ? React.createElement(TitleText, null, title) : null,
        message != null ? React.createElement(MessageText, null, message) : null,
        children,
        Object.keys(buttons).map(key => {
            const { type = 'primary', label, onPress } = buttons[key];
            const handlePress = () => {
                if (onPress == null)
                    return bridge.resolve(key);
                return onPress().then(result => {
                    if (result)
                        bridge.resolve(key);
                }, error => showError(error));
            };
            return (React.createElement(MainButton, { key: key, label: label, marginRem: 0.5, type: type, onPress: handlePress }));
        }),
        closeArrow ? React.createElement(ModalCloseArrow, { onPress: handleCancel }) : null));
}
