var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { ActivityIndicator, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { completeLogin } from '../../actions/LoginCompleteActions';
import s from '../../common/locales/strings';
import { QrCode } from '../common/QrCode';
import { Airship, showError } from '../services/AirshipInstance';
import { withTheme } from '../services/ThemeContext';
import { ModalCloseArrow } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
import { MessageText, TitleText } from '../themed/ThemedText';
/**
 * Dispatch this redux action to launch the QR code modal
 * with the correct props.
 */
export const showQrCodeModal = () => (dispatch, getState, imports) => {
    const { context, accountOptions } = imports;
    Airship.show(bridge => (React.createElement(QrCodeModal, { bridge: bridge, accountOptions: accountOptions, context: context, completeLogin: (account) => __awaiter(void 0, void 0, void 0, function* () { return yield dispatch(completeLogin(account)); }) })));
};
class QrCodeModalComponent extends React.Component {
    constructor(props) {
        super(props);
        this.cleanups = [];
        this.handleStart = (username) => {
            this.setState({ username });
        };
        this.handleDone = (account) => {
            const { bridge, completeLogin } = this.props;
            completeLogin(account).catch(showError);
            bridge.resolve();
        };
        this.handleError = (error) => {
            const { bridge } = this.props;
            showError(error);
            bridge.resolve();
        };
        this.state = {};
    }
    componentDidMount() {
        this.prepareLobby().catch(showError);
    }
    componentWillUnmount() {
        for (const cleanup of this.cleanups)
            cleanup();
        if (this.state.pendingLogin != null) {
            // Close the request, ignoring errors (in case it is already closed):
            Promise.resolve(this.state.pendingLogin.cancelRequest()).catch(() => { });
        }
    }
    prepareLobby() {
        return __awaiter(this, void 0, void 0, function* () {
            const { accountOptions, context } = this.props;
            const out = yield context.requestEdgeLogin(Object.assign(Object.assign({}, accountOptions), { 
                // These are no longer used in recent core versions:
                // @ts-expect-error
                displayImageUrl: 'https://github.com/Airbitz/edge-brand-guide/blob/master/Logo/Mark/Edge-Final-Logo_Mark-Green.png', displayName: 'Edge Wallet' }));
            if (out.state != null) {
                // New core versions have the callbacks on the request:
                out.watch('state', state => {
                    if (state === 'started' && out.username != null) {
                        this.handleStart(out.username);
                    }
                    if (state === 'done' && out.account != null) {
                        this.handleDone(out.account);
                    }
                    if (state === 'error')
                        this.handleError(out.error);
                });
            }
            else {
                // Older core versions have the callbacks on the context:
                this.cleanups = [
                    // @ts-expect-error
                    context.on('login', account => this.handleDone(account)),
                    // @ts-expect-error
                    context.on('loginStart', ({ username }) => this.handleStart(username)),
                    // @ts-expect-error
                    context.on('loginError', ({ error }) => this.handleError(error))
                ];
            }
            this.setState({ pendingLogin: out });
        });
    }
    render() {
        const { bridge, theme } = this.props;
        const { pendingLogin, username } = this.state;
        const styles = getStyles(theme);
        return (React.createElement(ThemedModal, { bridge: bridge, onCancel: () => bridge.resolve() },
            React.createElement(TitleText, null, s.strings.qr_modal_title),
            React.createElement(MessageText, null, username != null
                ? sprintf(s.strings.qr_modal_started, username)
                : s.strings.qr_modal_message),
            React.createElement(View, { style: styles.qrContainer }, username != null || pendingLogin == null ? (React.createElement(ActivityIndicator, { color: theme.primaryText })) : (React.createElement(QrCode, { data: 'edge://edge/' + pendingLogin.id, size: theme.rem(14) }))),
            React.createElement(ModalCloseArrow, { onPress: () => bridge.resolve() })));
    }
}
const getStyles = cacheStyles((theme) => ({
    qrContainer: {
        alignItems: 'center',
        justifyContent: 'center',
        minHeight: theme.rem(16),
        padding: theme.rem(1)
    }
}));
const QrCodeModal = withTheme(QrCodeModalComponent);
