import * as React from 'react';
import { Platform, View } from 'react-native';
import s from '../../common/locales/strings';
import { showError } from '../services/AirshipInstance';
import { EdgeTextFieldOutlined } from '../themed/EdgeTextFieldOutlined';
import { MainButton } from '../themed/MainButton';
import { ModalCloseArrow } from '../themed/ModalParts';
import { ThemedModal } from '../themed/ThemedModal';
import { MessageText, TitleText } from '../themed/ThemedText';
export class TextInputModal extends React.Component {
    constructor(props) {
        super(props);
        this.handleCancel = () => {
            const { bridge } = this.props;
            if (!this.state.spinning)
                bridge.resolve(undefined);
        };
        this.handleChangeText = (text) => {
            this.setState({ errorMessage: undefined, text });
        };
        this.handleSubmit = () => {
            const { bridge, onSubmit } = this.props;
            if (onSubmit == null)
                return bridge.resolve(this.state.text);
            this.setState({ spinning: true });
            onSubmit(this.state.text).then(result => {
                if (result === true) {
                    bridge.resolve(this.state.text);
                }
                else if (result === false) {
                    this.setState({ spinning: false });
                }
                else {
                    this.setState({ errorMessage: result, spinning: false });
                }
            }, error => {
                this.setState({ spinning: false });
                showError(error);
            });
        };
        this.state = { spinning: false, text: '' };
    }
    render() {
        const { bridge, inputLabel, message, submitLabel = s.strings.submit, title, autoCapitalize, autoCorrect, keyboardType, returnKeyType, secureTextEntry } = this.props;
        const { errorMessage, text, spinning } = this.state;
        return (React.createElement(ThemedModal, { bridge: bridge, onCancel: this.handleCancel },
            title != null ? React.createElement(TitleText, null, title) : null,
            message != null ? React.createElement(MessageText, null, message) : null,
            React.createElement(EdgeTextFieldOutlined
            // Text input props:
            , { 
                // Text input props:
                autoCapitalize: autoCapitalize, autoCorrect: autoCorrect, keyboardType: keyboardType, label: inputLabel, returnKeyType: returnKeyType, secureTextEntry: secureTextEntry, 
                // Our props:
                autoFocus: true, error: errorMessage, marginRem: 1, onChangeText: this.handleChangeText, onSubmitEditing: this.handleSubmit, showSearchIcon: false, value: text }),
            // Hack around the Android keyboard glitch:
            Platform.OS === 'android' ? React.createElement(View, { style: { flex: 1 } }) : null,
            spinning ? (React.createElement(MainButton, { alignSelf: "center", disabled: true, marginRem: 0.5, spinner: true })) : (React.createElement(MainButton, { alignSelf: "center", label: submitLabel, marginRem: 0.5, onPress: this.handleSubmit })),
            React.createElement(ModalCloseArrow, { onPress: this.handleCancel })));
    }
}
