import * as React from 'react';
import { View } from 'react-native';
import s from '../../common/locales/strings';
import * as Styles from '../../styles/index';
import { MaybeProvideLoginUi } from '../publicApi/LoginUiProvider';
import { PublicChangePasswordScene, ResecurePasswordScene } from '../scenes/existingAccout/ChangePasswordScene';
import { PublicChangePinScene, ResecurePinScene } from '../scenes/existingAccout/ChangePinScene';
import { PublicChangeRecoveryScene } from '../scenes/existingAccout/ChangeRecoveryScene';
import { OtpRepairScene } from '../scenes/existingAccout/OtpRepairScene';
import { SecurityAlertsScene } from '../scenes/existingAccout/SecurityAlertsScene';
import { LandingScene } from '../scenes/LandingScene';
import { LoadingScene } from '../scenes/LoadingScene';
import { NewAccountPasswordScene } from '../scenes/newAccount/NewAccountPasswordScene';
import { NewAccountPinScene } from '../scenes/newAccount/NewAccountPinScene';
import { NewAccountReviewScene } from '../scenes/newAccount/NewAccountReviewScene';
import { NewAccountTosScene } from '../scenes/newAccount/NewAccountTosScene';
import { NewAccountUsernameScene } from '../scenes/newAccount/NewAccountUsernameScene';
import { NewAccountWelcomeScene } from '../scenes/newAccount/NewAccountWelcomeScene';
import { OtpErrorScene } from '../scenes/OtpErrorScene';
import { PasswordLoginScene } from '../scenes/PasswordLoginScene';
import { PinLoginScene } from '../scenes/PinLoginScene';
import { RecoveryLoginScene } from '../scenes/RecoveryLoginScene';
import { WaitScene } from '../scenes/WaitScene';
import { connect } from '../services/ReduxStore';
class RouterComponent extends React.Component {
    render() {
        const { SceneStyle } = Styles;
        return (React.createElement(MaybeProvideLoginUi, null,
            React.createElement(View, { accessible: true, style: SceneStyle }, this.renderContent())));
    }
    renderContent() {
        switch (this.props.scene.currentScene) {
            case 'ChangePasswordScene':
                return React.createElement(PublicChangePasswordScene, { showHeader: this.props.showHeader });
            case 'ChangePinScene':
                return React.createElement(PublicChangePinScene, { showHeader: this.props.showHeader });
            case 'ChangeRecoveryScene':
                return React.createElement(PublicChangeRecoveryScene, { showHeader: this.props.showHeader });
            case 'NewAccountWelcomeScene':
                return React.createElement(NewAccountWelcomeScene, { branding: this.props.branding });
            case 'NewAccountUsernameScene':
                return React.createElement(NewAccountUsernameScene, { branding: this.props.branding });
            case 'NewAccountPasswordScene':
                return React.createElement(NewAccountPasswordScene, null);
            case 'NewAccountPinScene':
                return React.createElement(NewAccountPinScene, null);
            case 'NewAccountTosScene':
                return React.createElement(NewAccountTosScene, { branding: this.props.branding });
            case 'NewAccountWaitScene':
                return (React.createElement(WaitScene, { title: s.strings.great_job, message: s.strings.hang_tight + '\n' + s.strings.secure_account }));
            case 'NewAccountReviewScene':
                return React.createElement(NewAccountReviewScene, null);
            case 'LandingScene':
                return React.createElement(LandingScene, { branding: this.props.branding });
            case 'LoadingScene':
                return React.createElement(LoadingScene, { branding: this.props.branding });
            case 'OtpScene':
                return React.createElement(OtpErrorScene, null);
            case 'OtpRepairScene':
                return React.createElement(OtpRepairScene, null);
            case 'PasswordScene':
                return React.createElement(PasswordLoginScene, { branding: this.props.branding });
            case 'PinScene':
                return React.createElement(PinLoginScene, { branding: this.props.branding });
            case 'RecoveryLoginScene':
                return React.createElement(RecoveryLoginScene, null);
            case 'ResecurePasswordScene':
                return React.createElement(ResecurePasswordScene, { showHeader: this.props.showHeader });
            case 'ResecurePinScene':
                return React.createElement(ResecurePinScene, { showHeader: this.props.showHeader });
            case 'SecurityAlertScene':
                return React.createElement(SecurityAlertsScene, null);
        }
    }
}
export const Router = connect((state) => ({
    scene: state.scene
}), (dispatch) => ({}))(RouterComponent);
