import * as React from 'react';
import { initializeLogin } from '../../actions/LoginInitActions';
import { updateFontStyles } from '../../constants/Fonts';
import { Router } from '../navigation/Router';
import { ReduxStore } from '../services/ReduxStore';
import { changeFont } from '../services/ThemeContext';
export function LoginScreen(props) {
    const { fontDescription = { regularFontFamily: 'System' } } = props;
    const { regularFontFamily, headingFontFamily = regularFontFamily } = fontDescription;
    // Always update legacy fonts:
    updateFontStyles(regularFontFamily, headingFontFamily);
    // Update theme fonts if they are different:
    React.useEffect(() => changeFont(regularFontFamily, headingFontFamily), [
        regularFontFamily,
        headingFontFamily
    ]);
    return (React.createElement(ReduxStore, { imports: {
            accountOptions: props.accountOptions,
            context: props.context,
            onComplete: () => { },
            onLogin: props.onLogin,
            recoveryKey: props.recoveryLogin,
            skipSecurityAlerts: props.skipSecurityAlerts,
            username: props.username,
            customPermissionsFunction: props.customPermissionsFunction
        }, initialAction: initializeLogin() },
        React.createElement(Router, { branding: {
                appId: props.appId,
                appName: props.appName,
                backgroundImage: props.backgroundImage,
                landingSceneText: props.landingScreenText,
                parentButton: props.parentButton,
                primaryLogo: props.primaryLogo,
                primaryLogoCallback: props.primaryLogoCallback
            }, showHeader: true })));
}
