var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { FlatList, Keyboard, TouchableOpacity, TouchableWithoutFeedback, View } from 'react-native';
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { sprintf } from 'sprintf-js';
import { launchPasswordRecovery, login } from '../../actions/LoginAction';
import { deleteUserFromDevice } from '../../actions/UserActions';
import s from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import * as Styles from '../../styles/index';
import { scale } from '../../util/scaling';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { UserListItem } from '../abSpecific/UserListItem';
import { BackgroundImage } from '../common/BackgroundImage';
import { Button } from '../common/Button';
import { FormField } from '../common/FormField';
import { HeaderParentButtons } from '../common/HeaderParentButtons';
import { ButtonsModal } from '../modals/ButtonsModal';
import { showQrCodeModal } from '../modals/QrCodeModal';
import { TextInputModal } from '../modals/TextInputModal';
import { Airship, showError } from '../services/AirshipInstance';
import { connect } from '../services/ReduxStore';
import { MainButton } from '../themed/MainButton';
class PasswordLoginSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handlePasswordChange = (password) => {
            this.setState({ errorMessage: '', password });
        };
        this.handleSubmit = () => __awaiter(this, void 0, void 0, function* () {
            const { login, saveOtpError, username } = this.props;
            const { password } = this.state;
            this.handleBlur();
            Keyboard.dismiss();
            const attempt = { type: 'password', username, password };
            yield login(attempt).catch(error => {
                if (error != null && error.name === 'OtpError') {
                    saveOtpError(attempt, error);
                }
                else {
                    console.log(error);
                    const errorMessage = error != null ? error.message : '';
                    this.setState({ errorMessage });
                }
            });
        });
        this.handleBlur = () => {
            Keyboard.dismiss();
            this.setState({
                focusFirst: false,
                focusSecond: false
            });
        };
        this.handleDelete = (username) => {
            const { deleteUserFromDevice } = this.props;
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.delete_account, message: sprintf(s.strings.delete_username_account, username), buttons: {
                    ok: { label: s.strings.delete },
                    cancel: { label: s.strings.cancel, type: 'secondary' }
                } })))
                .then((button) => __awaiter(this, void 0, void 0, function* () {
                if (button !== 'ok')
                    return;
                return yield deleteUserFromDevice(username);
            }))
                .catch(showError);
        };
        this.renderRow = (data) => {
            return (React.createElement(UserListItem, { data: data.item, style: styles.listItem, onClick: this.handleSelectUser, onDelete: this.handleDelete }));
        };
        this.handleToggleUsernameList = () => {
            Keyboard.dismiss();
            this.setState({
                focusFirst: false,
                focusSecond: false,
                usernameList: !this.state.usernameList
            });
        };
        this.handleFocus1 = () => {
            this.setState({
                focusFirst: true,
                focusSecond: false
            });
        };
        this.handleFocus2 = () => {
            this.setState({
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleSetNextFocus = () => {
            this.setState({
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleSelectUser = (username) => {
            this.handleChangeUsername(username);
            this.setState({
                usernameList: false
            });
            const details = this.props.previousUsers.find(info => info.username === username);
            if (details != null &&
                (details.pinEnabled || (details.touchEnabled && this.props.touch))) {
                this.props.gotoPinLoginPage();
                return;
            }
            this.handleSetNextFocus();
        };
        this.handleChangeUsername = (data) => {
            this.setState({ errorMessage: '' });
            this.props.updateUsername(data);
        };
        this.handleForgotPassword = () => {
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, onSubmit: this.props.handlePasswordRecovery, title: s.strings.password_recovery, message: s.strings.initiate_password_recovery, inputLabel: s.strings.recovery_token })));
        };
        this.handleCreateAccount = () => {
            this.props.gotoCreatePage();
        };
        this.state = {
            errorMessage: '',
            focusFirst: true,
            focusSecond: false,
            password: '',
            usernameList: false
        };
    }
    render() {
        return (React.createElement(KeyboardAwareScrollView, { style: styles.container, keyboardShouldPersistTaps: "always", contentContainerStyle: styles.mainScrollView },
            React.createElement(BackgroundImage, { branding: this.props.branding, style: styles.backgroundImage, content: this.renderOverImage(), onPress: this.handleBlur })));
    }
    renderOverImage() {
        if (this.props.loginSuccess) {
            /* return (
              <View style={style.featureBox}>
                <Text>LOGIN SUCCESS</Text>
              </View>
            ) */
            return null;
        }
        return (React.createElement(View, { style: styles.featureBoxContainer },
            React.createElement(HeaderParentButtons, { branding: this.props.branding }),
            React.createElement(TouchableWithoutFeedback, { onPress: this.handleBlur },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: this.props.branding }),
                    this.renderUsername(),
                    React.createElement(View, { style: styles.shimTiny }),
                    React.createElement(FormField, { testID: "passwordFormField", style: styles.input2, onChangeText: this.handlePasswordChange, value: this.state.password, label: s.strings.password, error: this.state.errorMessage, autoCorrect: false, secureTextEntry: true, returnKeyType: "go", forceFocus: this.state.focusSecond, onFocus: this.handleFocus2, onSubmitEditing: this.handleSubmit }),
                    this.renderButtons()))));
    }
    renderUsername() {
        return (React.createElement(View, null,
            React.createElement(View, { style: styles.usernameWrapper },
                React.createElement(FormField, { testID: "usernameFormField", style: styles.input2, onChangeText: this.handleChangeUsername, value: this.props.username, label: s.strings.username, returnKeyType: "next", autoCorrect: false, autoFocus: this.state.focusFirst, forceFocus: this.state.focusFirst, onFocus: this.handleFocus1, onSubmitEditing: this.handleSetNextFocus }),
                React.createElement(TouchableOpacity, { style: styles.iconButton.container, onPress: this.handleToggleUsernameList }, this.state.usernameList ? (React.createElement(MaterialIcon, { name: "expand-less", size: styles.iconButton.iconSize, style: styles.iconButton.icon })) : (React.createElement(MaterialIcon, { name: "expand-more", size: styles.iconButton.iconSize, style: styles.iconButton.icon })))),
            this.state.usernameList && this.renderDropdownList()));
    }
    renderDropdownList() {
        return (React.createElement(FlatList, { style: styles.dropDownList, data: this.props.usernameOnlyList, renderItem: this.renderRow, keyExtractor: (item, index) => index.toString() }));
    }
    renderButtons() {
        const { handleQrModal } = this.props;
        return (React.createElement(View, { style: styles.buttonsBox },
            React.createElement(View, { style: styles.shimTiny }),
            React.createElement(Button, { onPress: this.handleForgotPassword, label: s.strings.forgot_password, downStyle: styles.forgotButton.downStyle, downTextStyle: styles.forgotButton.downTextStyle, upStyle: styles.forgotButton.upStyle, upTextStyle: styles.forgotButton.upTextStyle }),
            React.createElement(View, { style: styles.loginButtonBox },
                React.createElement(MainButton, { label: s.strings.login_button, testID: "loginButton", type: "secondary", onPress: this.handleSubmit })),
            React.createElement(Button, { testID: "createAccountButton", onPress: this.handleCreateAccount, label: s.strings.create_an_account, downStyle: styles.signupButton.downStyle, downTextStyle: styles.signupButton.downTextStyle, upStyle: styles.signupButton.upStyle, upTextStyle: styles.signupButton.upTextStyle }),
            React.createElement(TouchableOpacity, { onPress: handleQrModal },
                React.createElement(AntDesignIcon, { name: "qrcode", color: Constants.WHITE, size: scale(28) }))));
    }
}
const styles = {
    container: Styles.SceneStyle,
    mainScrollView: {
        position: 'relative',
        width: '100%',
        height: '100%'
    },
    backgroundImage: {
        flex: 1,
        alignItems: 'center',
        width: '100%',
        height: '100%'
    },
    featureBoxContainer: {
        width: '100%'
    },
    featureBox: {
        position: 'relative',
        top: scale(55),
        width: '100%',
        alignItems: 'center'
    },
    shimTiny: {
        width: '100%',
        height: scale(10)
    },
    loginButtonBox: {
        marginVertical: scale(10),
        width: '70%'
    },
    buttonsBox: {
        width: '100%',
        alignItems: 'center'
    },
    input2: {
        container: {
            position: 'relative',
            width: '70%',
            minHeight: scale(60)
        },
        baseColor: Constants.WHITE,
        tintColor: Constants.ACCENT_MINT,
        errorColor: Constants.ACCENT_RED,
        textColor: Constants.WHITE,
        affixTextStyle: {
            color: Constants.WHITE
        },
        titleTextStyle: {
            color: Constants.WHITE
        }
    },
    listItem: {
        container: {
            height: scale(40),
            width: '100%',
            backgroundColor: Constants.WHITE,
            borderBottomColor: Constants.GRAY_4,
            borderBottomWidth: 1,
            flexDirection: 'row',
            alignItems: 'center'
        },
        textComtainer: {
            flex: 9,
            height: '100%',
            flexDirection: 'column',
            justifyContent: 'space-around'
        },
        iconButton: {
            container: {
                flex: 1,
                flexDirection: 'row',
                alignItems: 'center',
                justifyContent: 'space-around',
                height: '100%'
            },
            icon: {
                color: Constants.PRIMARY
            },
            iconSize: scale(Constants.FONTS.defaultFontSize)
        },
        text: {
            color: Constants.PRIMARY,
            backgroundColor: Constants.TRANSPARENT,
            fontFamily: Constants.FONTS.fontFamilyRegular,
            marginLeft: scale(8),
            fontSize: scale(Constants.FONTS.defaultFontSize)
        }
    },
    forgotButton: {
        upStyle: Styles.TextOnlyButtonUpStyle,
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downStyle: Styles.TextOnlyButtonDownStyle
    },
    signupButton: {
        upStyle: Styles.TextOnlyButtonUpStyle,
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownStyle), { fontSize: scale(14), color: Constants.WHITE }),
        downStyle: Styles.TextOnlyButtonDownStyle
    },
    iconButton: {
        container: {
            position: 'absolute',
            right: 0,
            bottom: (scale(260) - scale(250)) * 1.6
        },
        icon: {
            color: Constants.WHITE
        },
        iconPressed: {
            color: Constants.SECONDARY
        },
        iconSize: scale(Constants.FONTS.defaultFontSize + 8),
        underlayColor: Constants.TRANSPARENT
    },
    usernameWrapper: {
        width: '100%',
        flexDirection: 'row'
    },
    dropDownList: {
        maxHeight: scale(200),
        backgroundColor: '#FFFFFF'
    }
};
export const PasswordLoginScene = connect((state) => ({
    loginSuccess: state.login.loginSuccess,
    previousUsers: state.previousUsers.userList,
    touch: state.touch,
    username: state.login.username,
    usernameOnlyList: state.previousUsers.usernameOnlyList
}), (dispatch) => ({
    deleteUserFromDevice(username) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(deleteUserFromDevice(username));
        });
    },
    gotoCreatePage() {
        dispatch({ type: 'NEW_ACCOUNT_WELCOME' });
    },
    gotoPinLoginPage() {
        dispatch({ type: 'START_PIN_LOGIN' });
    },
    handleQrModal() {
        Keyboard.dismiss();
        dispatch(showQrCodeModal());
    },
    login(attempt) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(login(attempt));
        });
    },
    saveOtpError(attempt, error) {
        dispatch({ type: 'OTP_ERROR', data: { attempt, error } });
    },
    updateUsername(data) {
        dispatch({ type: 'AUTH_UPDATE_USERNAME', data: data });
    },
    handlePasswordRecovery(recoveryKey) {
        return __awaiter(this, void 0, void 0, function* () {
            dispatch(launchPasswordRecovery(recoveryKey));
            return yield Promise.resolve(true);
        });
    }
}))(PasswordLoginSceneComponent);
