var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { FlatList, Keyboard, Platform, Text, TouchableWithoutFeedback, View } from 'react-native';
import { sprintf } from 'sprintf-js';
import { loginWithPin, loginWithTouch } from '../../actions/LoginAction';
import { deleteUserFromDevice } from '../../actions/UserActions';
import * as Assets from '../../assets/index';
import s from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import * as Styles from '../../styles/index';
import { scale, scaleH } from '../../util/scaling';
import { FourDigit } from '../abSpecific/FourDigitComponent';
import { LogoImageHeader } from '../abSpecific/LogoImageHeader';
import { PinKeypad } from '../abSpecific/PinKeypad';
import { UserListItem } from '../abSpecific/UserListItem';
import { BackgroundImage } from '../common/BackgroundImage';
import { Button } from '../common/Button';
import { HeaderParentButtons } from '../common/HeaderParentButtons';
import { ImageButton } from '../common/ImageButton';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { connect } from '../services/ReduxStore';
class PinLoginSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handleDelete = (username) => {
            const { deleteUserFromDevice } = this.props;
            this.setState({ focusOn: 'pin' });
            Keyboard.dismiss();
            Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.delete_account, message: sprintf(s.strings.delete_username_account, username), buttons: {
                    ok: { label: s.strings.delete },
                    cancel: { label: s.strings.cancel, type: 'secondary' }
                } })))
                .then((button) => __awaiter(this, void 0, void 0, function* () {
                if (button !== 'ok')
                    return;
                return yield deleteUserFromDevice(username);
            }))
                .catch(showError);
        };
        this.handleTouchId = () => {
            this.props.loginWithTouch(this.props.username);
        };
        this.handlePress = (value) => {
            const { loginWithPin, onChangeText, pin, username } = this.props;
            const newPin = value === 'back' ? pin.slice(0, -1) : pin.concat(value);
            onChangeText(newPin);
            if (newPin.length === 4)
                loginWithPin(username, newPin);
        };
        this.renderItems = (item) => {
            return (React.createElement(UserListItem, { data: item.item, style: styles.listItem, onClick: this.handleSelectUser, onDelete: this.handleDelete }));
        };
        this.handleSelectUser = (username) => {
            this.props.loginWithTouch(username);
            this.props.changeUser(username);
            this.setState({
                focusOn: 'pin'
            });
        };
        this.handleShowDrop = () => {
            this.setState({
                focusOn: 'List'
            });
        };
        this.handleHideDrop = () => {
            this.setState({
                focusOn: 'pin'
            });
        };
        this.renderTouchImage = () => {
            const { touch, userDetails } = this.props;
            const { touchEnabled } = userDetails;
            if (touchEnabled && touch === 'FaceID') {
                return (React.createElement(ImageButton, { style: { container: {}, image: {} }, source: Assets.FACE_ID, onPress: this.handleTouchId, disabled: this.props.isTouchIdDisabled }));
            }
            if (touchEnabled && touch === 'TouchID') {
                return (React.createElement(ImageButton, { style: { container: {}, image: {} }, source: Assets.TOUCH_ID, onPress: this.handleTouchId, disabled: this.props.isTouchIdDisabled }));
            }
            if (!touchEnabled || !touch) {
                return null;
            }
            return null;
        };
        this.renderTouchImageText = () => {
            const { touch, userDetails } = this.props;
            const { touchEnabled } = userDetails;
            if (touchEnabled && touch === 'FaceID') {
                return s.strings.use_faceId;
            }
            if (touchEnabled && touch === 'TouchID' && Platform.OS === 'ios') {
                return s.strings.use_touchId;
            }
            if (touchEnabled && touch === 'TouchID' && Platform.OS !== 'ios') {
                return s.strings.use_fingerprint;
            }
            return '';
        };
        this.state = {
            focusOn: 'pin'
        };
    }
    componentDidMount() {
        if (this.props.username && this.props.touch !== 'FaceID') {
            this.props.loginWithTouch(this.props.username);
        }
    }
    componentDidUpdate() {
        if (!this.props.userDetails.touchEnabled &&
            !this.props.userDetails.pinEnabled) {
            this.exitPin();
        }
    }
    render() {
        return (React.createElement(View, { style: styles.container },
            React.createElement(BackgroundImage, { branding: this.props.branding, style: styles.backgroundImage, content: this.renderOverImage() })));
    }
    renderOverImage() {
        const { pin, wait } = this.props;
        if (this.props.loginSuccess) {
            return null;
        }
        return (React.createElement(View, { style: styles.featureBoxContainer },
            React.createElement(HeaderParentButtons, { branding: Object.assign(Object.assign({}, this.props.branding), { parentButton: {
                        text: s.strings.exit_pin,
                        callback: this.exitPin.bind(this)
                    } }) }),
            React.createElement(TouchableWithoutFeedback, { onPress: this.handleHideDrop },
                React.createElement(View, { style: styles.featureBox },
                    React.createElement(LogoImageHeader, { branding: this.props.branding }),
                    React.createElement(View, { style: styles.featureBoxBody }, this.renderBottomHalf()))),
            React.createElement(View, { style: styles.spacer_full }),
            this.props.userDetails.pinEnabled && (React.createElement(PinKeypad, { disabled: wait > 0 || pin.length === 4, onPress: this.handlePress }))));
    }
    renderBottomHalf() {
        const { errorMessage, isLoggingInWithPin, pin, wait } = this.props;
        if (this.state.focusOn === 'pin') {
            return (React.createElement(View, { style: styles.innerView },
                React.createElement(Button, { onPress: this.handleShowDrop, label: this.props.username, downStyle: styles.usernameButton.downStyle, downTextStyle: styles.usernameButton.downTextStyle, upStyle: styles.usernameButton.upStyle, upTextStyle: styles.usernameButton.upTextStyle }),
                this.props.userDetails.pinEnabled && (React.createElement(FourDigit, { error: wait > 0
                        ? `${errorMessage}: ${sprintf(s.strings.account_locked_for, wait)}`
                        : errorMessage, pin: pin, spinner: wait > 0 || pin.length === 4 || isLoggingInWithPin })),
                !this.props.userDetails.pinEnabled && React.createElement(View, { style: styles.spacer }),
                this.renderTouchImage(),
                React.createElement(Text, { style: styles.touchImageText }, this.renderTouchImageText())));
        }
        return (React.createElement(View, { style: styles.innerView },
            React.createElement(FlatList, { style: styles.listView, data: this.getDropdownItems(), renderItem: this.renderItems, keyExtractor: (item, index) => index.toString() })));
    }
    exitPin() {
        this.props.gotoLoginPage();
    }
    getDropdownItems() {
        const { userList, touch } = this.props;
        return userList
            .filter(user => user.pinEnabled || (touch && user.touchEnabled))
            .map(user => user.username);
    }
}
const styles = {
    container: Styles.SceneStyle,
    backgroundImage: {
        flex: 1,
        width: null,
        height: null,
        alignItems: 'center'
    },
    innerView: {
        height: '100%',
        width: '100%',
        justifyContent: 'flex-start',
        alignItems: 'center'
    },
    featureBoxContainer: {
        width: '100%',
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-around'
    },
    featureBox: {
        position: 'relative',
        top: scale(40),
        width: '100%',
        alignItems: 'center'
    },
    featureBoxBody: {
        height: scale(240),
        width: '100%'
    },
    thumbprintButton: {
        container: {
            position: 'absolute',
            top: 0,
            left: 0,
            width: '100%',
            flexDirection: 'column',
            alignItems: 'flex-end'
        },
        image: {
            position: 'relative',
            marginRight: '5%'
        }
    },
    listView: {
        height: scale(250),
        width: scaleH(160)
    },
    listItem: {
        container: {
            height: scale(40),
            width: '100%',
            backgroundColor: Constants.PRIMARY,
            flexDirection: 'row',
            alignItems: 'center'
        },
        textComtainer: {
            flex: 25,
            height: '100%',
            flexDirection: 'column',
            justifyContent: 'space-around'
        },
        iconButton: {
            container: {
                flex: 5,
                flexDirection: 'row',
                alignItems: 'center',
                justifyContent: 'space-around',
                height: '100%'
            },
            icon: {
                color: Constants.WHITE
            },
            iconSize: scale(Constants.FONTS.defaultFontSize)
        },
        text: {
            paddingLeft: scale(20),
            color: Constants.WHITE,
            backgroundColor: Constants.TRANSPARENT,
            fontFamily: Constants.FONTS.fontFamilyRegular,
            fontSize: scale(Constants.FONTS.defaultFontSize)
        }
    },
    dropInput: {
        container: {
            width: 200,
            height: scale(30),
            // backgroundColor: Constants.WHITE,
            marginBottom: scale(20)
        }
    },
    usernameButton: {
        upStyle: Styles.TextOnlyButtonUpStyle,
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpStyle), { color: Constants.WHITE, fontSize: scale(24) }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownStyle), { color: Constants.WHITE, fontSize: scale(24) }),
        downStyle: Styles.TextOnlyButtonDownStyle
    },
    exitButton: {
        upStyle: Styles.TextOnlyButtonUpStyle,
        upTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextUpStyle), { color: Constants.WHITE, fontSize: scale(16) }),
        downTextStyle: Object.assign(Object.assign({}, Styles.TextOnlyButtonTextDownStyle), { color: Constants.WHITE, fontSize: scale(16) }),
        downStyle: Styles.TextOnlyButtonDownStyle
    },
    spacer: {
        marginTop: scale(35)
    },
    spacer_full: {
        flex: 1,
        zIndex: -100
    },
    touchImageText: {
        marginTop: scale(8),
        color: Constants.ACCENT_MINT
    }
};
export const PinLoginScene = connect((state) => {
    var _a;
    return ({
        errorMessage: state.login.errorMessage || '',
        isLoggingInWithPin: state.login.isLoggingInWithPin,
        isTouchIdDisabled: state.login.loginSuccess ||
            !!state.login.wait ||
            state.login.isLoggingInWithPin ||
            (state.login.pin ? state.login.pin.length : 0) === 4,
        loginSuccess: state.login.loginSuccess,
        pin: state.login.pin || '',
        touch: state.touch,
        userDetails: (_a = state.previousUsers.userList.find(user => user.username === state.login.username)) !== null && _a !== void 0 ? _a : {
            username: state.login.username,
            pinEnabled: false,
            touchEnabled: false
        },
        userList: state.previousUsers.userList,
        username: state.login.username,
        wait: state.login.wait
    });
}, (dispatch) => ({
    changeUser: (data) => {
        dispatch({ type: 'AUTH_UPDATE_USERNAME', data: data });
    },
    deleteUserFromDevice(username) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(deleteUserFromDevice(username));
        });
    },
    gotoLoginPage: () => {
        dispatch({ type: 'START_PASSWORD_LOGIN' });
    },
    loginWithTouch(username) {
        dispatch(loginWithTouch(username)).catch(showError);
    },
    loginWithPin(username, pin) {
        dispatch(loginWithPin(username, pin));
    },
    onChangeText(pin) {
        dispatch({ type: 'AUTH_UPDATE_PIN', data: pin });
    }
}))(PinLoginSceneComponent);
