var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Text, View } from 'react-native';
import { login } from '../../actions/LoginAction';
import s from '../../common/locales/strings';
import * as Constants from '../../constants/index';
import * as Styles from '../../styles/index';
import { Button } from '../common/Button';
import { FormField } from '../common/FormField';
import { Header } from '../common/Header';
import SafeAreaViewGradient from '../common/SafeAreaViewGradient';
import { connect } from '../services/ReduxStore';
class RecoveryLoginSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.renderHeader = () => {
            if (this.props.showHeader) {
                return React.createElement(Header, { onBack: this.props.onBack, title: s.strings.recovery });
            }
            return null;
        };
        this.handleSubmit = () => {
            const { login, recoveryKey, saveOtpError, username } = this.props;
            const errorOne = this.state.answer1.length < 1;
            const errorTwo = this.state.answer2.length < 1;
            this.setState({ errorOne, errorTwo });
            if (errorOne || errorTwo)
                return;
            const attempt = {
                type: 'recovery',
                recoveryKey,
                username,
                answers: [this.state.answer1, this.state.answer2]
            };
            login(attempt).catch(error => {
                if (error != null && error.name === 'OtpError') {
                    saveOtpError(attempt, error);
                }
                else {
                    console.log(error);
                    const errorMessage = error != null
                        ? error.name === 'PasswordError'
                            ? s.strings.recovery_error
                            : error.message
                        : 'Unknown error';
                    this.setState({ errorMessage });
                }
            });
        };
        this.handleAnswer1 = (arg) => {
            this.setState({
                answer1: arg
            });
        };
        this.handleAnswer2 = (arg) => {
            this.setState({
                answer2: arg
            });
        };
        this.state = {
            answer1: '',
            answer2: '',
            errorOne: false,
            errorTwo: false,
            errorMessage: ''
        };
    }
    renderError() {
        if (this.state.errorMessage) {
            return (React.createElement(View, null,
                React.createElement(View, { style: styles.shim }),
                React.createElement(Text, { style: styles.errorText }, this.state.errorMessage),
                React.createElement(View, { style: styles.shim })));
        }
        return React.createElement(View, { style: styles.shim });
    }
    render() {
        // const middle = this.renderForm(RecoverPasswordSceneStyles)
        const form1Style = this.state.errorOne ? styles.inputError : styles.input;
        const form2Style = this.state.errorTwo ? styles.inputError : styles.input;
        return (React.createElement(SafeAreaViewGradient, null,
            React.createElement(View, { style: styles.scene },
                this.renderHeader(),
                React.createElement(View, { style: styles.body },
                    React.createElement(View, { style: styles.questionRow },
                        React.createElement(Text, { style: styles.questionText }, this.props.question1)),
                    React.createElement(View, { style: styles.answerRow },
                        React.createElement(FormField, { style: form1Style, autoCorrect: false, autoCapitalize: "none", onChangeText: this.handleAnswer1, value: this.state.answer1, label: s.strings.your_answer_label, error: s.strings.answer_case_sensitive })),
                    React.createElement(View, { style: styles.shim }),
                    React.createElement(View, { style: styles.questionRow },
                        React.createElement(Text, { style: styles.questionText }, this.props.question2)),
                    React.createElement(View, { style: styles.answerRow },
                        React.createElement(FormField, { style: form2Style, autoCorrect: false, autoCapitalize: "none", onChangeText: this.handleAnswer2, value: this.state.answer2, label: s.strings.your_answer_label, error: s.strings.answer_case_sensitive })),
                    React.createElement(View, { style: styles.buttonContainer },
                        this.renderError(),
                        React.createElement(Button, { onPress: this.handleSubmit, downStyle: styles.submitButton.downStyle, downTextStyle: styles.submitButton.downTextStyle, upStyle: styles.submitButton.upStyle, upTextStyle: styles.submitButton.upTextStyle, label: s.strings.submit }))))));
    }
}
const styles = {
    scene: Object.assign(Object.assign({}, Styles.SceneStyle), { marginTop: 5 }),
    body: {
        padding: 18
    },
    questionRow: {
        height: 50,
        width: '100%',
        borderBottomWidth: 1,
        borderColor: Constants.GRAY_2
    },
    questionText: {
        color: Constants.GRAY_2,
        fontSize: 18
    },
    answerRow: {
        width: '100%',
        height: 100
    },
    buttonContainer: {
        width: '100%',
        alignItems: 'center'
        // height: THEME.BUTTONS.HEIGHT
    },
    input: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite), { errorColor: Constants.GRAY_2, baseColor: Constants.GRAY_2, textColor: Constants.GRAY_2, titleTextStyle: {
            color: Constants.GRAY_2
        }, affixTextStyle: {
            color: Constants.GRAY_2
        }, container: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite.container), { width: '100%' }) }),
    inputError: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite), { errorColor: Constants.ACCENT_RED, baseColor: Constants.ACCENT_RED, textColor: Constants.ACCENT_RED, titleTextStyle: {
            color: Constants.ACCENT_RED
        }, affixTextStyle: {
            color: Constants.ACCENT_RED
        }, container: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite.container), { width: '100%' }) }),
    shim: {
        height: 20
    },
    submitButton: {
        upStyle: Styles.PrimaryButtonUpStyle,
        upTextStyle: Styles.PrimaryButtonUpTextStyle,
        downTextStyle: Styles.PrimaryButtonUpTextStyle,
        downStyle: Styles.PrimaryButtonDownStyle
    },
    errorText: {
        color: Constants.ACCENT_RED,
        width: '90%',
        fontSize: 14,
        textAlign: 'center',
        paddingBottom: 5
    }
};
export const RecoveryLoginScene = connect((state) => ({
    question1: state.passwordRecovery.userQuestions.length > 0
        ? state.passwordRecovery.userQuestions[0]
        : s.strings.choose_recovery_question,
    question2: state.passwordRecovery.userQuestions.length > 1
        ? state.passwordRecovery.userQuestions[1]
        : s.strings.choose_recovery_question,
    recoveryKey: state.passwordRecovery.recoveryKey || '',
    showHeader: true,
    username: state.login.username
}), (dispatch) => ({
    onBack() {
        dispatch({ type: 'START_PASSWORD_LOGIN' });
    },
    login(attempt) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(login(attempt));
        });
    },
    saveOtpError(attempt, error) {
        dispatch({ type: 'OTP_ERROR', data: { attempt, error } });
    }
}))(RecoveryLoginSceneComponent);
