import * as React from 'react';
import { Keyboard, KeyboardAvoidingView, ScrollView, View } from 'react-native';
import { validateConfirmPassword, validatePassword } from '../../../actions/CreateAccountActions';
import { onComplete } from '../../../actions/WorkflowActions';
import s from '../../../common/locales/strings';
import * as Constants from '../../../constants/index';
import * as Styles from '../../../styles/index';
import { scale } from '../../../util/scaling';
import { getAccount } from '../../../util/selectors';
import { PasswordStatus } from '../../abSpecific/PasswordStatusComponent';
import { Button } from '../../common/Button';
import { FormField } from '../../common/FormField';
import { Header } from '../../common/Header';
import SafeAreaView from '../../common/SafeAreaViewGradient';
import { ButtonsModal } from '../../modals/ButtonsModal';
import { Airship, showError } from '../../services/AirshipInstance';
import { connect } from '../../services/ReduxStore';
class ChangePasswordSceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.handleFocusSwitch = () => {
            this.setState({
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleSubmit = () => {
            const { account, password, onDone } = this.props;
            if (!this.props.passwordStatus ||
                this.props.error !== '' ||
                this.props.error2 !== '') {
                return;
            }
            if (this.props.password &&
                this.props.password !== this.props.confirmPassword) {
                this.props.validateConfirmPassword(this.props.confirmPassword);
                return;
            }
            Keyboard.dismiss();
            this.setState({ isProcessing: true });
            account
                .changePassword(password)
                .then(onDone)
                .catch(error => {
                this.setState({ isProcessing: false });
                showError(error);
            });
        };
        this.renderHeader = () => {
            if (this.props.showHeader) {
                return (React.createElement(Header, { onBack: this.props.onBack, onSkip: this.props.onSkip, title: s.strings.change_password }));
            }
            return null;
        };
        this.renderInterior = () => {
            return (React.createElement(View, { style: styles.innerView },
                React.createElement(PasswordStatus, null),
                React.createElement(FormField, { autoFocus: this.state.focusFirst, error: this.props.createPasswordErrorMessage, label: s.strings.new_password, onChangeText: (password) => this.props.validatePassword(password), onSubmitEditing: this.handleFocusSwitch, returnKeyType: "next", secureTextEntry: true, style: styles.inputBox, value: this.props.password }),
                React.createElement(View, { style: { height: scale(20) } }),
                React.createElement(FormField, { autoFocus: this.state.focusSecond, error: this.props.confirmPasswordErrorMessage, returnKeyType: "go", secureTextEntry: true, value: this.props.confirmPassword, label: s.strings.re_enter_new_password, onChangeText: (password) => this.props.validateConfirmPassword(password), onSubmitEditing: this.handleSubmit, style: styles.inputBox }),
                React.createElement(View, { style: { height: scale(40) } }),
                React.createElement(Button, { onPress: this.handleSubmit, downStyle: styles.nextButton.downStyle, downTextStyle: styles.nextButton.downTextStyle, upStyle: styles.nextButton.upStyle, upTextStyle: styles.nextButton.upTextStyle, label: s.strings.done, isThinking: this.state.isProcessing, doesThink: true })));
        };
        this.renderMain = () => {
            if (this.state.focusSecond) {
                return (React.createElement(KeyboardAvoidingView, { style: styles.pageContainer, contentContainerStyle: styles.pageContainer, behavior: "position", keyboardVerticalOffset: -150 }, this.renderInterior()));
            }
            return React.createElement(View, { style: styles.pageContainer }, this.renderInterior());
        };
        this.state = {
            isProcessing: false,
            focusFirst: true,
            focusSecond: false
        };
    }
    render() {
        return (React.createElement(SafeAreaView, null,
            React.createElement(View, { style: styles.scene },
                this.renderHeader(),
                React.createElement(ScrollView, { keyboardShouldPersistTaps: "always" },
                    this.renderMain(),
                    React.createElement(View, { style: { backgroundColor: Constants.WHITE, height: 360 } })))));
    }
}
const styles = {
    scene: Object.assign({}, Styles.SceneStyle),
    pageContainer: {
        width: '100%',
        alignItems: 'center',
        flex: 1
    },
    innerView: {
        height: '100%',
        width: '100%',
        alignItems: 'center'
    },
    nextButton: {
        upStyle: Styles.PrimaryButtonUpScaledStyle,
        upTextStyle: Styles.PrimaryButtonUpTextScaledStyle,
        downTextStyle: Styles.PrimaryButtonUpTextScaledStyle,
        downStyle: Styles.PrimaryButtonDownScaledStyle
    },
    inputBox: Object.assign(Object.assign({}, Styles.MaterialInputOnWhiteScaled), { marginTop: scale(15) })
};
export const PublicChangePasswordScene = connect((state) => {
    var _a, _b;
    return ({
        account: getAccount(state),
        confirmPassword: state.create.confirmPassword || '',
        confirmPasswordErrorMessage: (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : '',
        createPasswordErrorMessage: (_b = state.create.createPasswordErrorMessage) !== null && _b !== void 0 ? _b : '',
        error: state.create.confirmPasswordErrorMessage || '',
        error2: state.create.createPasswordErrorMessage || '',
        password: state.create.password || '',
        passwordStatus: state.create.passwordStatus
    });
}, (dispatch) => ({
    onDone() {
        Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })))
            .then(() => dispatch(onComplete()))
            .catch(showError);
    },
    onBack() {
        dispatch(onComplete());
    },
    validateConfirmPassword(password) {
        dispatch(validateConfirmPassword(password));
    },
    validatePassword(password) {
        dispatch(validatePassword(password));
    }
}))(ChangePasswordSceneComponent);
export const ResecurePasswordScene = connect((state) => {
    var _a, _b;
    return ({
        account: getAccount(state),
        confirmPassword: state.create.confirmPassword || '',
        confirmPasswordErrorMessage: (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : '',
        createPasswordErrorMessage: (_b = state.create.createPasswordErrorMessage) !== null && _b !== void 0 ? _b : '',
        error: state.create.confirmPasswordErrorMessage || '',
        error2: state.create.createPasswordErrorMessage || '',
        password: state.create.password || '',
        passwordStatus: state.create.passwordStatus
    });
}, (dispatch) => ({
    onDone() {
        dispatch({ type: 'RESECURE_PIN' });
    },
    onSkip() {
        dispatch(dispatch({ type: 'RESECURE_PIN' }));
    },
    validateConfirmPassword(password) {
        dispatch(validateConfirmPassword(password));
    },
    validatePassword(password) {
        dispatch(validatePassword(password));
    }
}))(ChangePasswordSceneComponent);
