var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Dimensions, FlatList, Keyboard, Platform, View } from 'react-native';
import MaterialIcon from 'react-native-vector-icons/MaterialIcons';
import { sendRecoveryEmail, shareRecovery } from '../../../actions/PasswordRecoveryActions';
import { onComplete } from '../../../actions/WorkflowActions';
import s from '../../../common/locales/strings';
import * as Colors from '../../../constants/Colors';
import * as Styles from '../../../styles/index';
import { isIphoneX } from '../../../util/isIphoneX';
import { scale } from '../../../util/scaling';
import { getAccount } from '../../../util/selectors';
import { Button } from '../../common/Button';
import { FormField } from '../../common/FormField';
import { Header } from '../../common/Header';
import { TextRowComponent } from '../../common/ListItems/TextRowComponent';
import { TextAndIconButton } from '../../common/TextAndIconButton';
import { ButtonsModal } from '../../modals/ButtonsModal';
import { TextInputModal } from '../../modals/TextInputModal';
import { Airship, showError } from '../../services/AirshipInstance';
import { connect } from '../../services/ReduxStore';
import { MessageText, Strong } from '../../themed/ThemedText';
class ChangeRecoverySceneComponent extends React.Component {
    constructor(props) {
        super(props);
        this.renderHeader = () => {
            if (this.props.showHeader) {
                return React.createElement(Header, { onBack: this.props.onBack, title: s.strings.recovery });
            }
            return null;
        };
        this.handleDisable = () => {
            this.disableRecovery().catch(showError);
        };
        this.handleSubmit = () => {
            // Launch Modal full Scene
            const errorOne = this.state.answer1.length < 4;
            const errorTwo = this.state.answer2.length < 4;
            const errorQuestionOne = this.state.question1 === s.strings.choose_recovery_question;
            const errorQuestionTwo = this.state.question2 === s.strings.choose_recovery_question;
            this.setState({
                errorOne,
                errorTwo,
                errorQuestionOne,
                errorQuestionTwo
            });
            if (errorOne || errorTwo || errorQuestionOne || errorQuestionTwo) {
                return;
            }
            Keyboard.dismiss();
            this.enableRecovery().catch(showError);
        };
        this.handleQuestion1 = () => {
            this.setState({
                showQuestionPicker: true,
                focusFirst: true,
                focusSecond: false
            });
        };
        this.handleQuestion2 = () => {
            this.setState({
                showQuestionPicker: true,
                focusFirst: false,
                focusSecond: true
            });
        };
        this.handleAnswer1 = (arg) => {
            this.setState({
                answer1: arg
            });
        };
        this.handleAnswer2 = (arg) => {
            this.setState({
                answer2: arg
            });
        };
        this.handleQuestionSelected = (data) => {
            const question = data.question;
            if (this.state.focusFirst) {
                this.setState({
                    question1: question,
                    showQuestionPicker: false
                });
                return;
            }
            this.setState({
                question2: question,
                showQuestionPicker: false
            });
        };
        this.handleEnableEmail = () => __awaiter(this, void 0, void 0, function* () {
            const { account, onDone } = this.props;
            const emailAddress = yield Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, title: s.strings.save_recovery_token, message: s.strings.recovery_instructions_complete, inputLabel: s.strings.email_address, submitLabel: s.strings.next_label, keyboardType: "email-address", returnKeyType: "go" })));
            if (emailAddress == null)
                return false;
            const recoveryKey = yield account.changeRecovery([this.state.question1, this.state.question2], [this.state.answer1, this.state.answer2]);
            try {
                yield sendRecoveryEmail(emailAddress, account.username, recoveryKey);
            }
            catch (error) {
                yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.send_email_error_header, message: s.strings.email_error_modal, buttons: { ok: { label: s.strings.ok } } })));
                return false;
            }
            onDone();
            return true;
        });
        this.handleEnableShare = () => __awaiter(this, void 0, void 0, function* () {
            const { account, onDone } = this.props;
            const recoveryKey = yield account.changeRecovery([this.state.question1, this.state.question2], [this.state.answer1, this.state.answer2]);
            yield shareRecovery(account.username, recoveryKey);
            onDone();
            return true;
        });
        this.renderItems = (item) => {
            return (React.createElement(TextRowComponent, { data: item.item, title: item.item.question, onPress: this.handleQuestionSelected, numberOfLines: 3 }));
        };
        this.getQuestions = () => {
            const { questionsList } = this.props;
            const { focusFirst, focusSecond, question1, question2 } = this.state;
            const questionFilter = focusFirst ? question2 : focusSecond ? question1 : '';
            return questionsList.filter(item => item.question !== questionFilter);
        };
        this.renderQuestions = () => {
            return (React.createElement(View, { style: styles.body },
                React.createElement(FlatList, { style: styles.questionsList, data: this.getQuestions(), renderItem: this.renderItems, keyExtractor: (item, index) => index.toString() })));
        };
        this.renderForm = () => {
            const form1Style = this.state.errorOne ? styles.inputError : styles.input;
            const form2Style = this.state.errorTwo ? styles.inputError : styles.input;
            const errorMessageOne = this.state.errorOne
                ? s.strings.answers_four_chanracters
                : s.strings.answer_case_sensitive;
            const errorMessageTwo = this.state.errorTwo
                ? s.strings.answers_four_chanracters
                : s.strings.answer_case_sensitive;
            const questionOneStyle = this.state.errorQuestionOne
                ? styles.textIconButtonErrorError
                : styles.textIconButton;
            const questionTwoStyle = this.state.errorQuestionTwo
                ? styles.textIconButtonErrorError
                : styles.textIconButton;
            return (React.createElement(View, { style: styles.body },
                React.createElement(View, { style: styles.questionRow },
                    React.createElement(TextAndIconButton, { onPress: this.handleQuestion1, icon: React.createElement(MaterialIcon, { style: questionOneStyle.icon, name: "keyboard-arrow-down", size: questionOneStyle.iconSize }), style: questionOneStyle, numberOfLines: 2, title: this.state.question1 })),
                React.createElement(View, { style: styles.answerRow },
                    React.createElement(FormField, { style: form1Style, autoFocus: this.state.focusFirst || this.props.isEnabled, autoCorrect: false, autoCapitalize: "none", onChangeText: this.handleAnswer1, value: this.state.answer1, label: s.strings.your_answer_label, error: errorMessageOne })),
                React.createElement(View, { style: styles.questionRow },
                    React.createElement(TextAndIconButton, { onPress: this.handleQuestion2, icon: React.createElement(MaterialIcon, { style: questionTwoStyle.icon, name: "keyboard-arrow-down", size: questionTwoStyle.iconSize }), style: questionTwoStyle, numberOfLines: 2, title: this.state.question2 })),
                React.createElement(View, { style: styles.answerRow },
                    React.createElement(FormField, { style: form2Style, autoFocus: this.state.focusSecond, autoCorrect: false, autoCapitalize: "none", onChangeText: this.handleAnswer2, value: this.state.answer2, label: s.strings.your_answer_label, error: errorMessageTwo })),
                this.renderButtons()));
        };
        const [question1 = s.strings.choose_recovery_question, question2 = s.strings.choose_recovery_question] = props.userQuestions;
        this.state = {
            question1,
            question2,
            answer1: '',
            answer2: '',
            showQuestionPicker: false,
            focusFirst: false,
            focusSecond: false,
            errorOne: false,
            errorTwo: false,
            errorQuestionOne: false,
            errorQuestionTwo: false
        };
    }
    enableRecovery() {
        return __awaiter(this, void 0, void 0, function* () {
            const buttons = {
                email: {
                    label: s.strings.confirm_email,
                    onPress: this.handleEnableEmail
                },
                share: {
                    label: s.strings.confirm_share,
                    onPress: this.handleEnableShare
                },
                cancel: { label: s.strings.cancel, type: 'secondary' }
            };
            if (Platform.OS === 'android')
                delete buttons.email;
            // Ask which way to send the key:
            yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.confirm_recovery_questions, buttons: buttons },
                React.createElement(MessageText, null, this.state.question1),
                React.createElement(MessageText, null,
                    React.createElement(Strong, null, this.state.answer1)),
                React.createElement(MessageText, null, this.state.question2),
                React.createElement(MessageText, null,
                    React.createElement(Strong, null, this.state.answer2)))));
        });
    }
    disableRecovery() {
        return __awaiter(this, void 0, void 0, function* () {
            const { account, onDone } = this.props;
            yield account.deleteRecovery();
            Keyboard.dismiss();
            this.setState({
                question1: s.strings.choose_recovery_question,
                question2: s.strings.choose_recovery_question
            });
            yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, message: s.strings.recovery_disabled, buttons: { ok: { label: s.strings.ok } } })));
            onDone();
        });
    }
    renderButtons() {
        if (this.props.isEnabled) {
            return (React.createElement(View, { style: styles.buttonContainer },
                React.createElement(View, { style: styles.shim }),
                React.createElement(Button, { onPress: this.handleSubmit, downStyle: styles.submitButton.downStyle, downTextStyle: styles.submitButton.downTextStyle, upStyle: styles.submitButton.upStyle, upTextStyle: styles.submitButton.upTextStyle, label: s.strings.save }),
                React.createElement(View, { style: styles.shim }),
                React.createElement(Button, { onPress: this.handleDisable, downStyle: styles.disableButton.downStyle, downTextStyle: styles.disableButton.downTextStyle, upStyle: styles.disableButton.upStyle, upTextStyle: styles.disableButton.upTextStyle, label: s.strings.disable_password_recovery })));
        }
        return (React.createElement(View, { style: styles.buttonContainer },
            React.createElement(View, { style: styles.shim }),
            React.createElement(Button, { onPress: this.handleSubmit, downStyle: styles.submitButton.downStyle, downTextStyle: styles.submitButton.downTextStyle, upStyle: styles.submitButton.upStyle, upTextStyle: styles.submitButton.upTextStyle, label: s.strings.done })));
    }
    render() {
        const middle = this.state.showQuestionPicker
            ? this.renderQuestions()
            : this.renderForm();
        return (React.createElement(View, { style: styles.scene },
            this.renderHeader(),
            middle));
    }
}
const styles = {
    scene: Object.assign({}, Styles.SceneStyle),
    body: {
        padding: scale(18)
    },
    questionRow: {
        height: scale(60),
        width: '100%',
        borderColor: Colors.GRAY_2,
        borderBottomWidth: scale(2)
    },
    answerRow: {
        width: '100%',
        height: scale(80)
    },
    buttonContainer: {
        width: '100%',
        alignItems: 'center'
    },
    input: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite), { errorColor: Colors.GRAY_2, baseColor: Colors.GRAY_2, textColor: Colors.GRAY_2, titleTextStyle: {
            color: Colors.GRAY_2
        }, affixTextStyle: {
            color: Colors.GRAY_2
        }, container: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite.container), { width: '100%' }) }),
    inputError: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite), { errorColor: Colors.ACCENT_RED, baseColor: Colors.ACCENT_RED, textColor: Colors.ACCENT_RED, titleTextStyle: {
            color: Colors.ACCENT_RED
        }, affixTextStyle: {
            color: Colors.ACCENT_RED
        }, container: Object.assign(Object.assign({}, Styles.MaterialInputOnWhite.container), { width: '100%' }) }),
    shim: {
        height: scale(20)
    },
    textIconButton: Styles.TextAndIconButtonAlignEdgesStyle,
    textIconButtonErrorError: Object.assign(Object.assign({}, Styles.TextAndIconButtonAlignEdgesStyle), { text: Object.assign(Object.assign({}, Styles.TextAndIconButtonAlignEdgesStyle.text), { color: Colors.ACCENT_RED }), icon: Object.assign(Object.assign({}, Styles.TextAndIconButtonAlignEdgesStyle.icon), { color: Colors.ACCENT_RED }) }),
    submitButton: {
        upStyle: Styles.PrimaryWidthButtonUpStyle,
        upTextStyle: Styles.PrimaryButtonUpTextStyle,
        downTextStyle: Styles.PrimaryButtonUpTextStyle,
        downStyle: Styles.PrimaryWidthButtonDownStyle
    },
    disableButton: {
        upStyle: Styles.DefaultWidthButtonUpStyle,
        upTextStyle: Styles.DefaultButtonUpTextStyle,
        downTextStyle: Styles.DefaultButtonDownTextStyle,
        downStyle: Styles.DefaultWidthButtonDownStyle
    },
    questionsList: {
        width: '100%',
        height: Dimensions.get('window').height - (isIphoneX ? scale(125) : scale(110)),
        borderColor: Colors.GRAY_3,
        borderWidth: 1
    }
};
export const PublicChangeRecoveryScene = connect((state) => ({
    account: getAccount(state),
    isEnabled: state.passwordRecovery.userQuestions.length > 0,
    questionsList: state.passwordRecovery.questionsList,
    userQuestions: state.passwordRecovery.userQuestions
}), (dispatch) => ({
    onBack() {
        dispatch(onComplete());
    },
    onDone() {
        dispatch(onComplete());
    }
}))(ChangeRecoverySceneComponent);
