var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import { sprintf } from 'sprintf-js';
import { requestOtpReset } from '../../../actions/LoginOtpActions';
import { onComplete } from '../../../actions/WorkflowActions';
import s from '../../../common/locales/strings';
import { toLocalTime } from '../../../util/utils';
import { showResetModal } from '../../modals/OtpResetModal';
import { showQrCodeModal } from '../../modals/QrCodeModal';
import { TextInputModal } from '../../modals/TextInputModal';
import { Airship, showError } from '../../services/AirshipInstance';
import { connect } from '../../services/ReduxStore';
import { DividerWithText } from '../../themed/DividerWithText';
import { IconHeaderRow } from '../../themed/IconHeaderRow';
import { LinkRow } from '../../themed/LinkRow';
import { ThemedScene } from '../../themed/ThemedScene';
import { MessageText, Warning } from '../../themed/ThemedText';
class OtpRepairSceneComponent extends React.Component {
    constructor() {
        super(...arguments);
        this.handleBackupModal = () => {
            const { account, onBack, saveOtpError } = this.props;
            const handleSubmit = (otpKey) => __awaiter(this, void 0, void 0, function* () {
                try {
                    if (account.repairOtp == null) {
                        throw new Error('Wrong edge-core-js version');
                    }
                    yield account.repairOtp(otpKey);
                    onBack();
                    return true;
                }
                catch (error) {
                    // Translate known errors:
                    if (error != null && error.name === 'OtpError') {
                        saveOtpError(account, error);
                        return s.strings.backup_key_incorrect;
                    }
                    if (error != null && error.message === 'Unexpected end of data') {
                        return s.strings.backup_key_incorrect;
                    }
                    showError(error);
                    return false;
                }
            });
            Airship.show(bridge => (React.createElement(TextInputModal, { bridge: bridge, onSubmit: handleSubmit, title: s.strings.otp_backup_code_modal_title, message: s.strings.otp_instructions, inputLabel: s.strings.backup_key_label, submitLabel: s.strings.submit, autoCapitalize: "characters", returnKeyType: "done" })));
        };
    }
    render() {
        const { handleQrModal, otpError, otpResetDate } = this.props;
        const isIp = otpError.reason === 'ip';
        // Find the automatic login date:
        let date = otpResetDate;
        if (otpError.voucherActivates != null)
            date = otpError.voucherActivates;
        return (React.createElement(ThemedScene, { onBack: this.props.onBack, title: s.strings.otp_header_repair },
            React.createElement(IconHeaderRow, { renderIcon: theme => (React.createElement(Warning, null,
                    React.createElement(FontAwesome, { name: "exclamation-triangle", size: theme.rem(2.5) }))) },
                React.createElement(MessageText, null,
                    React.createElement(Warning, null, isIp
                        ? s.strings.otp_repair_header_ip
                        : s.strings.otp_repair_header_2fa))),
            React.createElement(DividerWithText, { label: s.strings.to_fix }),
            React.createElement(MessageText, null, s.strings.otp_scene_approve),
            React.createElement(DividerWithText, null),
            React.createElement(LinkRow, { label: s.strings.otp_scene_qr, onPress: handleQrModal }),
            isIp ? null : (React.createElement(React.Fragment, null,
                React.createElement(DividerWithText, null),
                React.createElement(LinkRow, { label: s.strings.otp_backup_code_modal_title, onPress: this.handleBackupModal }))),
            date == null ? null : (React.createElement(React.Fragment, null,
                React.createElement(DividerWithText, null),
                React.createElement(MessageText, null, sprintf(s.strings.otp_scene_wait, toLocalTime(date))))),
            otpError.resetToken == null || date != null ? null : (React.createElement(React.Fragment, null,
                React.createElement(DividerWithText, null),
                React.createElement(LinkRow, { label: s.strings.disable_otp_button_two, onPress: () => showResetModal(this.props.requestOtpReset) })))));
    }
}
export const OtpRepairScene = connect((state) => {
    const { account } = state;
    const { otpError, otpResetDate } = state.login;
    if (account == null || otpError == null) {
        throw new Error('Missing OtpError for OTP repair scene');
    }
    return { account, otpError, otpResetDate };
}, (dispatch) => ({
    onBack() {
        dispatch(onComplete());
    },
    handleQrModal() {
        dispatch(showQrCodeModal());
    },
    requestOtpReset() {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(requestOtpReset());
        });
    },
    saveOtpError(account, error) {
        dispatch({ type: 'START_OTP_REPAIR', data: { account, error } });
    }
}))(OtpRepairSceneComponent);
