import * as React from 'react';
import { KeyboardAvoidingView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validateConfirmPassword, validatePassword } from '../../../actions/CreateAccountActions';
import s from '../../../common/locales/strings';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { EdgeText } from '../../themed/EdgeText';
import { EdgeTextFieldOutlined } from '../../themed/EdgeTextFieldOutlined';
import { Fade } from '../../themed/Fade';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { PasswordStatus } from '../../themed/PasswordStatus';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountPasswordSceneComponent = ({ confirmPassword, confirmPasswordErrorMessage, createPasswordErrorMessage, password, onDone, onBack, validateConfirmPassword, validatePassword, isPasswordStatusExists, isPasswordPassed, theme }) => {
    const styles = getStyles(theme);
    const [focusFirst, setFocusFirst] = React.useState(true);
    const [focusSecond, setFocusSecond] = React.useState(false);
    const handleFocusSwitch = () => {
        setFocusFirst(false);
        setFocusSecond(true);
    };
    const handleNext = () => {
        if (!isPasswordStatusExists)
            return;
        if (confirmPasswordErrorMessage !== '' ||
            createPasswordErrorMessage !== '') {
            logEvent('Signup_Password_Invalid');
            return;
        }
        if (password && password !== confirmPassword) {
            validateConfirmPassword(confirmPassword);
            logEvent('Signup_Password_Invalid');
            return;
        }
        logEvent('Signup_Password_Valid');
        onDone();
    };
    const renderInterior = () => {
        return (React.createElement(React.Fragment, null,
            isPasswordStatusExists ? (React.createElement(PasswordStatus, { marginRem: [0.5, 0, 1.25] })) : (React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, s.strings.password_desc)),
            React.createElement(EdgeTextFieldOutlined, { value: password, secureTextEntry: true, returnKeyType: "next", label: s.strings.password, autoFocus: focusFirst, onChangeText: validatePassword, onSubmitEditing: handleFocusSwitch, isClearable: true, showSearchIcon: false, marginRem: [0, 0.75, 1.25] }),
            React.createElement(EdgeTextFieldOutlined, { value: confirmPassword, secureTextEntry: true, returnKeyType: "go", label: s.strings.confirm_password, autoFocus: focusSecond, onChangeText: validateConfirmPassword, onSubmitEditing: handleNext, isClearable: true, showSearchIcon: false, marginRem: [0, 0.75, 1.25] }),
            React.createElement(FormError, { marginRem: [0, 0.75], invisible: !(confirmPasswordErrorMessage || createPasswordErrorMessage) }, confirmPasswordErrorMessage || createPasswordErrorMessage),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: isPasswordPassed &&
                        password === confirmPassword &&
                        !confirmPasswordErrorMessage &&
                        !createPasswordErrorMessage, hidden: true },
                    React.createElement(MainButton, { label: s.strings.next_label, type: "secondary", onPress: handleNext })))));
    };
    return (React.createElement(ThemedScene, { onBack: onBack, title: s.strings.choose_title_password }, focusSecond ? (React.createElement(KeyboardAvoidingView, { style: styles.container, behavior: "position", keyboardVerticalOffset: -150 }, renderInterior())) : (React.createElement(View, { style: styles.container }, renderInterior()))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        overflow: 'hidden'
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25),
        marginTop: theme.rem(2.25)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(1)
    }
}));
export const NewAccountPasswordScene = connect((state) => ({
    confirmPassword: state.create.confirmPassword || '',
    confirmPasswordErrorMessage: state.create.confirmPasswordErrorMessage || '',
    createPasswordErrorMessage: state.create.createPasswordErrorMessage || '',
    password: state.create.password || '',
    isPasswordStatusExists: !!state.passwordStatus,
    isPasswordPassed: Boolean(state.passwordStatus && state.passwordStatus.passed)
}), (dispatch) => ({
    onDone() {
        dispatch({ type: 'NEW_ACCOUNT_PIN' });
    },
    onBack() {
        dispatch({ type: 'NEW_ACCOUNT_USERNAME' });
    },
    validateConfirmPassword(password) {
        dispatch(validateConfirmPassword(password));
    },
    validatePassword(password) {
        dispatch(validatePassword(password));
    }
}))(withTheme(NewAccountPasswordSceneComponent));
