import * as React from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import s from '../../../common/locales/strings';
import { useScrollToEnd } from '../../../hooks/useScrollToEnd';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { DigitInput, MAX_PIN_LENGTH } from '../../themed/DigitInput';
import { EdgeText } from '../../themed/EdgeText';
import { Fade } from '../../themed/Fade';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountPinSceneComponent = ({ pinErrorMessage, pin, onBack, onDone, theme }) => {
    const styles = getStyles(theme);
    const showNext = pin.length === MAX_PIN_LENGTH && !pinErrorMessage;
    const scrollViewRef = useScrollToEnd(showNext);
    const handleNext = () => {
        // validation.
        // is there no error message,
        if (pin.length !== MAX_PIN_LENGTH || pinErrorMessage) {
            logEvent(`Signup_PIN_Invalid`);
            return;
        }
        onDone();
    };
    return (React.createElement(ThemedScene, { onBack: onBack, title: s.strings.choose_title_pin },
        React.createElement(ScrollView, { ref: scrollViewRef, style: styles.content },
            React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, s.strings.pin_desc),
            React.createElement(DigitInput, null),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: showNext },
                    React.createElement(MainButton, { label: s.strings.next_label, type: "secondary", onPress: handleNext }))))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(2.25)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(5),
        minHeight: theme.rem(3 + 15) // 15 is a hack to avoid the keyboard
    }
}));
export const NewAccountPinScene = connect((state) => ({
    pin: state.create.pin,
    pinErrorMessage: state.create.pinErrorMessage
}), (dispatch) => ({
    onDone() {
        dispatch({ type: 'NEW_ACCOUNT_TOS' });
    },
    onBack() {
        dispatch({ type: 'NEW_ACCOUNT_PASSWORD' });
    }
}))(withTheme(NewAccountPinSceneComponent));
