import * as React from 'react';
import { ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { confirmAndFinish } from '../../../actions/CreateAccountActions';
import s from '../../../common/locales/strings';
import { useScrollToEnd } from '../../../hooks/useScrollToEnd';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { AccountInfo } from '../../themed/AccountInfo';
import { EdgeText } from '../../themed/EdgeText';
import { Fade } from '../../themed/Fade';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountReviewSceneComponent = ({ onDone, theme }) => {
    const styles = getStyles(theme);
    const [showNext, setShowNext] = React.useState(false);
    const scrollViewRef = useScrollToEnd(showNext);
    const handleNext = () => {
        logEvent(`Signup_Review_Done`);
        onDone();
    };
    return (React.createElement(ThemedScene, { title: s.strings.review },
        React.createElement(ScrollView, { ref: scrollViewRef, contentContainerStyle: styles.content },
            React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, s.strings.almost_done),
            React.createElement(FormError, { marginRem: [0, 0, 2], title: s.strings.write_and_store, numberOfLines: 2, isWarning: true }, s.strings.warning_message),
            React.createElement(AccountInfo, { marginRem: [0, 2.5], onOpen: () => setShowNext(true) }),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: showNext },
                    React.createElement(MainButton, { label: s.strings.next_label, type: "secondary", onPress: handleNext }))))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(2)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(2)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(5),
        minHeight: theme.rem(3)
    }
}));
export const NewAccountReviewScene = connect((state) => ({}), (dispatch) => ({
    onDone() {
        dispatch(confirmAndFinish());
    }
}))(withTheme(NewAccountReviewSceneComponent));
