import * as React from 'react';
import { Alert, Linking, ScrollView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { createUser } from '../../../actions/CreateAccountActions';
import s from '../../../common/locales/strings';
import { useScrollToEnd } from '../../../hooks/useScrollToEnd';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { Checkbox } from '../../themed/Checkbox';
import { EdgeText } from '../../themed/EdgeText';
import { Fade } from '../../themed/Fade';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const TermsAndConditionsSceneComponent = ({ branding, agreeToConditionAndCreateUser, createErrorMessage, clearCreateErrorMessagecircleFilled, onBack, password, pin, username, theme }) => {
    const styles = getStyles(theme);
    const [termValues, setTermValues] = React.useState([
        false,
        false,
        false,
        false
    ]);
    const showNext = !termValues.includes(false);
    const scrollViewRef = useScrollToEnd(showNext);
    if (createErrorMessage) {
        Alert.alert(s.strings.create_account_error_title, s.strings.create_account_error_message + '\n' + createErrorMessage, [{ text: s.strings.ok }]);
        clearCreateErrorMessagecircleFilled();
    }
    const { appName = s.strings.app_name_default } = branding;
    const terms = [
        sprintf(s.strings.terms_one, appName),
        s.strings.terms_two,
        sprintf(s.strings.terms_three, appName),
        sprintf(s.strings.terms_four, appName)
    ];
    const handleStatusChange = (index, value) => {
        const newTermValues = [...termValues];
        newTermValues[index] = value;
        setTermValues(newTermValues);
    };
    const handleNextPress = () => {
        logEvent(`Signup_Terms_Agree_and_Create_User`);
        agreeToConditionAndCreateUser({
            username,
            password,
            pin
        });
    };
    return (React.createElement(ThemedScene, { onBack: onBack, title: s.strings.account_confirmation },
        React.createElement(ScrollView, { ref: scrollViewRef, contentContainerStyle: styles.content },
            React.createElement(EdgeText, { style: styles.subtitle }, `${s.strings.review}: ${s.strings.read_understod_2}`),
            terms.map((term, index) => (React.createElement(Checkbox, { key: index, textStyle: styles.term, value: termValues[index], onChange: (value) => handleStatusChange(index, value), marginRem: [0, 0, 1.33, 0] }, term))),
            React.createElement(EdgeText, { style: styles.agreeText, numberOfLines: 2, onPress: () => Linking.openURL('https://edge.app/terms-of-service/') },
                s.strings.read_understod_1,
                React.createElement(EdgeText, { style: styles.agreeTextLink }, s.strings.read_understod_2)),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: showNext },
                    React.createElement(MainButton, { label: s.strings.next_label, paddingRem: 0.7, type: "secondary", onPress: handleNextPress }))))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        marginHorizontal: theme.rem(0.5)
    },
    subtitle: {
        fontFamily: theme.fontFaceBold,
        color: theme.secondaryText,
        fontSize: theme.rem(1),
        marginBottom: theme.rem(2)
    },
    term: {
        fontSize: theme.rem(0.875)
    },
    agreeText: {
        width: '60%',
        alignSelf: 'center',
        marginTop: theme.rem(1),
        marginHorizontal: theme.rem(2),
        fontSize: theme.rem(0.875)
    },
    agreeTextLink: {
        fontSize: theme.rem(0.875),
        color: theme.linkText
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(2.75),
        minHeight: theme.rem(3)
    }
}));
export const NewAccountTosScene = connect((state) => ({
    createErrorMessage: state.create.createErrorMessage,
    password: state.create.password || '',
    pin: state.create.pin,
    username: state.create.username || ''
}), (dispatch) => ({
    agreeToConditionAndCreateUser(data) {
        dispatch(createUser(data));
    },
    clearCreateErrorMessagecircleFilled() {
        dispatch({ type: 'CLEAR_CREATE_ERROR_MESSAGE' });
    },
    onBack() {
        dispatch({ type: 'NEW_ACCOUNT_PIN' });
    }
}))(withTheme(TermsAndConditionsSceneComponent));
