var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { checkUsernameForAvailabilty, validateUsername } from '../../../actions/CreateAccountActions';
import s from '../../../common/locales/strings';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { EdgeText } from '../../themed/EdgeText';
import { EdgeTextFieldOutlined } from '../../themed/EdgeTextFieldOutlined';
import { Fade } from '../../themed/Fade';
import { FormError } from '../../themed/FormError';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountUsernameSceneComponent = ({ theme, onBack, branding, username, usernameErrorMessage, checkUsernameForAvailabilty, validateUsername }) => {
    const styles = getStyles(theme);
    const handleNext = () => __awaiter(void 0, void 0, void 0, function* () {
        if (usernameErrorMessage || !username) {
            return;
        }
        yield checkUsernameForAvailabilty(username);
    });
    return (React.createElement(ThemedScene, { onBack: onBack, title: s.strings.choose_title_username },
        React.createElement(View, { style: styles.content },
            React.createElement(EdgeText, { style: styles.description, numberOfLines: 2 }, sprintf(s.strings.username_desc, branding.appName || s.strings.app_name_default)),
            React.createElement(EdgeTextFieldOutlined, { autoCorrect: false, autoFocus: true, label: s.strings.username, onChangeText: validateUsername, onSubmitEditing: handleNext, returnKeyType: "go", value: username, isClearable: true, showSearchIcon: false, marginRem: [0, 0.75] }),
            React.createElement(FormError, { marginRem: [1, 0.75], invisible: usernameErrorMessage == null }, usernameErrorMessage),
            React.createElement(Fade, { hidden: true, visible: username.length > 0 &&
                    (usernameErrorMessage == null || usernameErrorMessage === '') },
                React.createElement(MainButton, { alignSelf: "center", label: s.strings.next_label, type: "secondary", onPress: handleNext })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        marginTop: theme.rem(2.25)
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25)
    }
}));
export const NewAccountUsernameScene = connect((state) => ({
    username: state.create.username || '',
    usernameErrorMessage: state.create.usernameErrorMessage
}), (dispatch) => ({
    onBack() {
        dispatch({ type: 'NEW_ACCOUNT_WELCOME' });
    },
    checkUsernameForAvailabilty(data) {
        return __awaiter(this, void 0, void 0, function* () {
            return yield dispatch(checkUsernameForAvailabilty(data));
        });
    },
    validateUsername(username) {
        dispatch(validateUsername(username));
    }
}))(withTheme(NewAccountUsernameSceneComponent));
