import * as React from 'react';
import { Image, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { sprintf } from 'sprintf-js';
import { LOGO_BIG, WELCOME_LOCK, WELCOME_SHIELD_KEY } from '../../../assets';
import s from '../../../common/locales/strings';
import * as Constants from '../../../constants/index';
import { logEvent } from '../../../util/analytics';
import { connect } from '../../services/ReduxStore';
import { withTheme } from '../../services/ThemeContext';
import { DividerLine } from '../../themed/DividerLine';
import { EdgeText } from '../../themed/EdgeText';
import { MainButton } from '../../themed/MainButton';
import { ThemedScene } from '../../themed/ThemedScene';
const NewAccountWelcomeSceneComponent = ({ theme, branding, onExit, onDone }) => {
    const styles = getStyles(theme);
    const appName = branding.appName || s.strings.app_name_default;
    return (React.createElement(ThemedScene, { onBack: onExit, title: s.strings.get_started },
        React.createElement(View, { style: styles.content },
            React.createElement(Image, { source: LOGO_BIG, style: styles.logo, resizeMode: "contain" }),
            React.createElement(EdgeText, { style: styles.welcome }, sprintf(s.strings.welcome, appName)),
            React.createElement(View, { style: styles.advantage },
                React.createElement(Image, { source: WELCOME_LOCK, style: styles.advantageImage, resizeMode: "contain" }),
                React.createElement(View, { style: styles.advantageTextContainer },
                    React.createElement(EdgeText, { style: styles.advantageTitle }, sprintf(s.strings.welcome_advantage_one_title, appName)),
                    React.createElement(EdgeText, { style: styles.advantageDescription, numberOfLines: 2 }, s.strings.welcome_advantage_one_description))),
            React.createElement(DividerLine, { marginRem: [1.5, 0.5] }),
            React.createElement(View, { style: styles.advantage },
                React.createElement(Image, { source: WELCOME_SHIELD_KEY, style: styles.advantageImage, resizeMode: "contain" }),
                React.createElement(View, { style: styles.advantageTextContainer },
                    React.createElement(EdgeText, { style: styles.advantageTitle }, s.strings.welcome_advantage_two_title),
                    React.createElement(EdgeText, { style: styles.advantageDescription, numberOfLines: 1 }, sprintf(s.strings.welcome_advantage_two_description, appName)),
                    React.createElement(EdgeText, { style: styles.advantageDescription, numberOfLines: 2 }, sprintf(s.strings.welcome_advantage_three_description, appName)))),
            React.createElement(View, { style: styles.actions },
                React.createElement(MainButton, { label: s.strings.get_started, type: "secondary", onPress: onDone })))));
};
const getStyles = cacheStyles((theme) => ({
    content: {
        flex: 1,
        alignItems: 'center'
    },
    logo: {
        height: theme.rem(2.25),
        marginTop: theme.rem(0.75),
        marginBottom: theme.rem(1)
    },
    welcome: {
        fontFamily: theme.fontFaceBold,
        color: theme.secondaryText,
        fontSize: theme.rem(1),
        marginBottom: theme.rem(2.375)
    },
    advantage: {
        flexDirection: 'row',
        alignItems: 'center',
        marginHorizontal: theme.rem(0.5)
    },
    advantageImage: {
        height: theme.rem(2),
        width: theme.rem(2),
        marginRight: theme.rem(0.5)
    },
    advantageTextContainer: {
        flex: 1
    },
    advantageTitle: {
        fontFamily: theme.fontFaceBold,
        color: Constants.GRAY_4,
        fontSize: theme.rem(1),
        marginBottom: theme.rem(0.5)
    },
    advantageDescription: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.75)
    },
    actions: {
        marginTop: theme.rem(4.5)
    }
}));
export const NewAccountWelcomeScene = connect((state) => ({}), (dispatch) => ({
    onExit() {
        dispatch({ type: 'START_LANDING' });
    },
    onDone() {
        logEvent(`Signup_Welcome_Next`);
        dispatch({ type: 'NEW_ACCOUNT_USERNAME' });
    }
}))(withTheme(NewAccountWelcomeSceneComponent));
