import * as React from 'react';
import { connect as rawConnect, Provider } from 'react-redux';
import { applyMiddleware, createStore } from 'redux';
import thunk from 'redux-thunk';
import { launchPasswordRecovery } from '../../actions/LoginAction';
import { rootReducer } from '../../reducers/RootReducer';
import { showError } from './AirshipInstance';
/**
 * Consolidates our Redux setup logic into one place.
 */
export class ReduxStore extends React.Component {
    constructor(props) {
        super(props);
        const { imports } = this.props;
        this.store = createStore(rootReducer, applyMiddleware(thunk.withExtraArgument(imports)));
        new Promise(resolve => {
            // @ts-expect-error Flow doesn't know about thunks at this point.
            resolve(this.store.dispatch(this.props.initialAction));
        }).catch(showError);
    }
    componentDidUpdate(prev) {
        const { recoveryKey } = this.props.imports;
        if (recoveryKey && recoveryKey !== prev.imports.recoveryKey) {
            this.store.dispatch(launchPasswordRecovery(recoveryKey));
        }
    }
    render() {
        const { children } = this.props;
        // @ts-expect-error: mismatching redux versions.
        return React.createElement(Provider, { store: this.store }, children);
    }
}
/**
 * The react-redux connect function, locked to our own Redux types
 * and fixed to take the same parameters as the TypeScript version.
 */
export function connect(mapStateToProps, mapDispatchToProps) {
    // @ts-expect-error
    return rawConnect(mapStateToProps, mapDispatchToProps);
}
