import * as React from 'react';
import { TouchableWithoutFeedback, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';
import { fixSides, mapSides, sidesToMargin } from '../../util/sides';
import { withTheme } from '../services/ThemeContext';
import { EdgeText } from './EdgeText';
const CheckboxComponent = ({ textStyle, disabled, children, value, onChange, marginRem, ellipsizeMode, numberOfLines, theme }) => {
    const styles = getStyles(theme);
    const spacings = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    return (React.createElement(TouchableWithoutFeedback, { onPress: () => onChange(!value), disabled: disabled },
        React.createElement(View, { style: [styles.container, spacings] },
            value ? (React.createElement(SimpleLineIcons, { style: styles.checkbox, name: "check", size: theme.rem(1.1), color: theme.iconTappable })) : (React.createElement(View, { style: [styles.checkbox, styles.unselected] })),
            React.createElement(EdgeText, { style: [styles.label, textStyle], ellipsizeMode: ellipsizeMode, numberOfLines: numberOfLines }, children))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flexDirection: 'row',
        alignItems: 'center',
        margin: theme.rem(0.5)
    },
    checkbox: {
        marginRight: theme.rem(1)
    },
    unselected: {
        borderWidth: 1,
        borderRadius: theme.rem(0.55),
        borderColor: theme.icon,
        width: theme.rem(1.1),
        height: theme.rem(1.1)
    },
    label: {
        flex: 1
    }
}));
export const Checkbox = withTheme(CheckboxComponent);
