import * as React from 'react';
import { TextInput, TouchableWithoutFeedback, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validatePin } from '../../actions/CreateAccountActions';
import { fixSides, mapSides, sidesToMargin } from '../../util/sides';
import { connect } from '../services/ReduxStore';
import { withTheme } from '../services/ThemeContext';
import { PinDots } from './PinDots';
export const MAX_PIN_LENGTH = 4;
const DigitInputComponent = ({ pin = '', maxPinLength = MAX_PIN_LENGTH, marginRem, theme, onChangeText }) => {
    const inputRef = React.useRef(null);
    const spacings = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    const styles = getStyles(theme);
    const handleRefocus = () => {
        if (inputRef.current !== null)
            inputRef.current.focus();
    };
    const handleUpdate = (pin) => {
        // Change pin only when input are numbers
        if (/^\d+$/.test(pin) || pin.length === 0) {
            onChangeText(pin);
        }
    };
    return (React.createElement(TouchableWithoutFeedback, { onPress: handleRefocus },
        React.createElement(View, { style: [styles.container, spacings] },
            React.createElement(View, { style: styles.interactiveContainer },
                React.createElement(PinDots, { pinLength: pin.length, maxLength: maxPinLength })),
            React.createElement(TextInput, { ref: inputRef, style: styles.input, onChangeText: handleUpdate, maxLength: maxPinLength, keyboardType: "number-pad", value: pin, autoFocus: true }))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        alignSelf: 'center'
    },
    interactiveContainer: {
        width: theme.rem(13)
    },
    input: {
        position: 'absolute',
        top: 0,
        left: 0,
        width: 0,
        height: 0,
        opacity: 0
    }
}));
export const DigitInput = connect((state) => ({
    pin: state.create.pin
}), (dispatch) => ({
    onChangeText(pin) {
        dispatch(validatePin(pin));
    }
}))(withTheme(DigitInputComponent));
