import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { fixSides, mapSides, sidesToMargin } from '../../util/sides.js';
import { useTheme } from '../services/ThemeContext.js';
/**
 * A horizontal line for dividing sections of the app.
 *
 * This is designed to "stick out" to the right of the content area,
 * touching the edge of the screen. Just add the same horizontal
 * margin to this component as you would to its siblings,
 * such as buttons or text fields, and everything will line up.
 */
export const DividerLine = (props) => {
    const { marginRem } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 0), theme.rem));
    margin.marginRight -= theme.rem(1);
    return React.createElement(View, { style: [styles.underline, margin] });
};
const getStyles = cacheStyles((theme) => ({
    underline: {
        borderTopWidth: theme.thinLineWidth,
        borderTopColor: theme.lineDivider,
        alignSelf: 'stretch'
    }
}));
