import * as React from 'react';
import Animated, { runOnJS, useAnimatedStyle, useSharedValue, withTiming } from 'react-native-reanimated';
const FadeComponent = (props) => {
    const { children, duration = 500, visible, hidden } = props;
    // We always fade in on first mount:
    const opacity = useSharedValue(0);
    const style = useAnimatedStyle(() => ({
        opacity: opacity.value
    }));
    // Animate the opacity & child lifecycle based on the visibility toggle:
    const [mounted, setMounted] = React.useState(visible);
    React.useEffect(() => {
        if (visible) {
            setMounted(true);
            opacity.value = withTiming(1, { duration });
        }
        else {
            opacity.value = withTiming(0, { duration }, (isComplete) => {
                if (!isComplete)
                    return;
                runOnJS(setMounted)(false);
            });
        }
    }, [duration, opacity, visible]);
    return (React.createElement(Animated.View, { style: style }, mounted || hidden ? children : null));
};
export const Fade = FadeComponent;
