import * as React from 'react';
import { Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import AntDesignIcon from 'react-native-vector-icons/AntDesign';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
export function LinkRow(props) {
    const { label, marginRem, onPress, renderIcon = (theme) => (React.createElement(AntDesignIcon, { name: "right", size: theme.rem(1) })) } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const spacingStyles = Object.assign({}, sidesToPadding(mapSides(fixSides(marginRem, 0.5), theme.rem)));
    return (React.createElement(TouchableOpacity, { style: [styles.container, spacingStyles], onPress: onPress },
        label != null ? React.createElement(Text, { style: styles.text }, label) : null,
        React.createElement(Text, { style: styles.icon }, renderIcon(theme))));
}
const getStyles = cacheStyles((theme) => {
    return {
        container: {
            alignItems: 'center',
            flexDirection: 'row'
        },
        icon: {
            color: theme.primaryButton,
            fontSize: theme.rem(1),
            marginLeft: theme.rem(1)
        },
        text: {
            color: theme.primaryButton,
            flex: 1,
            fontFamily: theme.fontFamily,
            fontSize: theme.rem(1)
        }
    };
});
