import * as React from 'react';
import { ActivityIndicator, Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { usePendingPress } from '../../hooks/usePendingPress';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
/**
 * A stand-alone button to perform the primary action in a modal or scene.
 */
export function MainButton(props) {
    const { alignSelf = 'auto', children, disabled = false, label, marginRem, onPress, type = 'primary', paddingRem, spinner = false, testID } = props;
    // `onPress` promise logic:
    const [pending, handlePress] = usePendingPress(onPress);
    // Styles:
    const theme = useTheme();
    const styles = getStyles(theme);
    const touchableStyle = type === 'primary' ? styles.primaryButton : styles.secondaryButton;
    const textStyle = type === 'primary' ? styles.primaryText : styles.secondaryText;
    const spinnerColor = type === 'primary' ? theme.primaryButtonText : theme.secondaryButtonText;
    const dynamicStyles = Object.assign(Object.assign({ alignSelf, opacity: disabled || pending ? 0.7 : 1 }, sidesToMargin(mapSides(fixSides(marginRem, 0), theme.rem))), sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem)));
    return (React.createElement(TouchableOpacity, { disabled: disabled || pending, style: [touchableStyle, dynamicStyles], testID: testID, onPress: handlePress },
        label != null && !pending ? (React.createElement(Text, { adjustsFontSizeToFit: true, minimumFontScale: 0.75, numberOfLines: 1, style: textStyle }, label)) : null,
        !pending ? children : null,
        spinner || pending ? (React.createElement(ActivityIndicator, { color: spinnerColor, style: styles.spinner })) : null));
}
const getStyles = cacheStyles((theme) => {
    const commonButton = {
        alignItems: 'center',
        borderRadius: theme.rem(0.25),
        borderWidth: theme.thinLineWidth,
        flexDirection: 'row',
        justifyContent: 'center',
        minHeight: theme.rem(3),
        minWidth: theme.rem(9)
    };
    const commonText = {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        marginHorizontal: theme.rem(0.5)
    };
    return {
        primaryButton: Object.assign(Object.assign({}, commonButton), { backgroundColor: theme.primaryButton, borderColor: theme.primaryButtonOutline }),
        primaryText: Object.assign(Object.assign({}, commonText), { color: theme.primaryButtonText }),
        secondaryButton: Object.assign(Object.assign({}, commonButton), { backgroundColor: theme.secondaryButton, borderColor: theme.secondaryButtonOutline }),
        secondaryText: Object.assign(Object.assign({}, commonText), { color: theme.secondaryButtonText }),
        // Common styles:
        spinner: {
            height: theme.rem(2),
            marginHorizontal: theme.rem(0.5)
        }
    };
});
