import * as React from 'react';
import { View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import FontAwesome from 'react-native-vector-icons/FontAwesome';
import SimpleLineIcons from 'react-native-vector-icons/SimpleLineIcons';
import s from '../../common/locales/strings';
import { fixSides, mapSides, sidesToMargin } from '../../util/sides';
import { connect } from '../services/ReduxStore';
import { withTheme } from '../services/ThemeContext';
import { EdgeText } from './EdgeText';
import { IconSignal } from './IconSignal';
const PasswordStatusComponent = ({ status, marginRem, theme }) => {
    const styles = getStyles(theme);
    const spacings = sidesToMargin(mapSides(fixSides(marginRem, 0.5), theme.rem));
    if (status === null)
        return null;
    const { list, passed } = status;
    return (React.createElement(View, { style: [styles.container, passed && styles.passedContainer, spacings] },
        React.createElement(View, { style: styles.top },
            React.createElement(IconSignal, { enabled: passed, enabledIcon: props => React.createElement(FontAwesome, Object.assign({}, props, { name: "check-circle" })), disabledIcon: props => React.createElement(SimpleLineIcons, Object.assign({}, props, { name: "info" })) }),
            React.createElement(EdgeText, { style: [styles.message, passed && styles.passed] }, s.strings.password_requirements)),
        list.map(({ title, value }) => (React.createElement(EdgeText, { key: title, style: [styles.case, value && styles.passed] }, `\u2022 ${title}`)))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        borderWidth: 0.25,
        borderRadius: theme.rem(0.25),
        borderColor: theme.warningText,
        padding: theme.rem(1),
        justifyContent: 'flex-start'
    },
    containerPassed: {
        borderColor: theme.positiveText
    },
    top: {
        flexDirection: 'row',
        alignItems: 'center',
        marginBottom: theme.rem(0.5)
    },
    message: {
        flexShrink: 1,
        color: theme.warningText,
        fontFamily: theme.fontFaceBold,
        fontSize: theme.rem(0.75),
        marginLeft: theme.rem(0.75)
    },
    case: {
        flexShrink: 1,
        color: theme.warningText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.75),
        marginBottom: theme.rem(0.15)
    },
    passed: {
        color: theme.positiveText
    },
    passedContainer: {
        borderColor: theme.positiveText
    }
}));
export const PasswordStatus = connect((state) => ({
    status: state.passwordStatus
}), () => ({}))(withTheme(PasswordStatusComponent));
