import * as React from 'react';
import { ActivityIndicator, Text, TouchableOpacity } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
export function AlertModalButton(props) {
    const { children, label, marginRem, onPress, paddingRem, spinner, type } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const buttonStyle = type === 'secondary'
        ? styles.alertModalSecondaryButton
        : styles.alertModalPrimaryButton;
    const textStyle = type === 'secondary'
        ? styles.alertModalSecondaryText
        : styles.alertModalPrimaryText;
    const spinnerColor = type === 'secondary'
        ? theme.alertModalTertiaryButtonText
        : theme.alertModalPrimaryButtonText;
    const spacingStyles = Object.assign(Object.assign({}, sidesToMargin(mapSides(fixSides(marginRem, 0), theme.rem))), sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem)));
    return (React.createElement(TouchableOpacity, { style: [buttonStyle, spacingStyles], onPress: onPress },
        label != null ? React.createElement(Text, { style: textStyle }, label) : null,
        spinner ? (React.createElement(ActivityIndicator, { color: spinnerColor, style: styles.spinner })) : null,
        children));
}
const getStyles = cacheStyles((theme) => {
    const commonButton = {
        alignItems: 'center',
        borderRadius: theme.rem(0.25),
        borderWidth: theme.thinLineWidth,
        flexDirection: 'row',
        justifyContent: 'center',
        minWidth: theme.rem(9)
    };
    const commonText = {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1),
        lineHeight: theme.rem(2),
        marginHorizontal: theme.rem(0.5)
    };
    return {
        alertModalPrimaryButton: Object.assign(Object.assign({}, commonButton), { backgroundColor: theme.alertModalPrimaryButton, borderColor: theme.alertModalPrimaryButtonOutline }),
        alertModalPrimaryText: Object.assign(Object.assign({}, commonText), { color: theme.alertModalPrimaryButtonText }),
        alertModalSecondaryButton: Object.assign(Object.assign({}, commonButton), { backgroundColor: theme.alertModalTertiaryButton, borderColor: theme.alertModalTertiaryButtonOutline }),
        alertModalSecondaryText: Object.assign(Object.assign({}, commonText), { color: theme.alertModalTertiaryButtonText }),
        spinner: { height: theme.rem(2) }
    };
});
