import * as React from 'react';
import { SafeAreaView, StyleSheet, Text, TouchableOpacity, View } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
import { cacheStyles } from 'react-native-patina';
import FontAwesome5 from 'react-native-vector-icons/FontAwesome5';
import s from '../../common/locales/strings';
import { fixSides, mapSides, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { DividerLine } from './DividerLine';
export function ThemedScene(props) {
    const { children, onBack, onSkip, paddingRem, title, noUnderline = false } = props;
    const theme = useTheme();
    const styles = getStyles(theme);
    const hasHeader = onBack != null || onSkip != null || title != null;
    const containerStyle = Object.assign({ flex: 1 }, sidesToPadding(mapSides(fixSides(paddingRem, 0.5), theme.rem)));
    return (React.createElement(React.Fragment, null,
        React.createElement(LinearGradient, { style: StyleSheet.absoluteFill, start: { x: 0, y: 0 }, end: { x: 1, y: 0 }, colors: [theme.backgroundGradientLeft, theme.backgroundGradientRight] }),
        React.createElement(SafeAreaView, { style: { flex: 1 } },
            !hasHeader ? null : (React.createElement(View, { style: styles.headerButtons },
                onBack == null ? null : (React.createElement(TouchableOpacity, { style: styles.backButton, onPress: onBack },
                    React.createElement(FontAwesome5, { name: "chevron-left", size: theme.rem(1), color: theme.primaryText }))),
                onSkip == null ? null : (React.createElement(TouchableOpacity, { style: styles.skipButton, onPress: onSkip },
                    React.createElement(Text, { style: styles.skipText }, s.strings.skip))))),
            title == null ? null : React.createElement(Text, { style: styles.titleText }, title),
            !hasHeader || noUnderline ? null : (React.createElement(DividerLine, { marginRem: [1, 1, 0] })),
            React.createElement(View, { style: containerStyle }, children))));
}
const getStyles = cacheStyles((theme) => ({
    headerButtons: {
        flexDirection: 'row',
        height: theme.rem(3)
    },
    backButton: {
        justifyContent: 'center',
        paddingHorizontal: theme.rem(1),
        position: 'absolute',
        bottom: 0,
        left: 0,
        top: 0
    },
    skipButton: {
        justifyContent: 'center',
        paddingHorizontal: theme.rem(1),
        position: 'absolute',
        bottom: 0,
        right: 0,
        top: 0
    },
    skipText: {
        color: theme.primaryText,
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(1)
    },
    titleText: {
        color: theme.primaryText,
        fontSize: theme.rem(1.25),
        fontFamily: theme.fontFaceBold,
        marginHorizontal: theme.rem(1)
    }
}));
