var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import * as React from 'react';
import { Text } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { useTheme } from '../services/ThemeContext';
/**
 * A lightweight wrapper around the React Native Text component,
 * which simply sets up some default styles.
 */
export function ThemedText(props) {
    const { style } = props, rest = __rest(props, ["style"]);
    const theme = useTheme();
    const styles = getStyles(theme);
    return React.createElement(Text, Object.assign({ style: [styles.themedText, style] }, rest));
}
/**
 * A scene or modal title.
 */
export function TitleText(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return React.createElement(Text, { style: styles.titleText }, props.children);
}
/**
 * A paragraph of body text within a modal or scene.
 */
export function MessageText(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return React.createElement(Text, { style: styles.messageText }, props.children);
}
/**
 * Use this component just like its HTML equivalent,
 * to wrap text that is of greater importance (bolder).
 */
export function Strong(props) {
    return React.createElement(Text, { style: { fontWeight: 'bold' } }, props.children);
}
/**
 * Wraps text that communicates danger, like unusually high fees.
 */
export function Warning(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return React.createElement(Text, { style: styles.warning }, props.children);
}
/**
 * Wraps text that communicates a problem, like insufficent funds.
 */
export function Error(props) {
    const theme = useTheme();
    const styles = getStyles(theme);
    return React.createElement(Text, { style: styles.error }, props.children);
}
const getStyles = cacheStyles((theme) => {
    const themedText = {
        color: theme.primaryText,
        fontFamily: theme.fontFamily,
        fontSize: theme.rem(1)
    };
    return {
        themedText,
        titleText: Object.assign(Object.assign({}, themedText), { fontSize: theme.rem(1.25), margin: theme.rem(0.5), textAlign: 'center' }),
        messageText: Object.assign(Object.assign({}, themedText), { margin: theme.rem(0.5), textAlign: 'left' }),
        warning: {
            color: theme.warningText
        },
        error: {
            color: theme.dangerText
        }
    };
});
