/**
 * Schedule a repeating task, with the specified gap between runs.
 */
export function makePeriodicTask(task, msGap, opts = {}) {
    const { onError = (e) => { } } = opts;
    // A started task will keep bouncing between running & waiting.
    // The `running` flag will be true in the running state,
    // and `timeout` will have a value in the waiting state.
    let running = false;
    let timeout;
    function run() {
        timeout = undefined;
        if (!out.started)
            return;
        running = true;
        new Promise(resolve => resolve(task())).catch(onError).then(wait, wait);
    }
    function wait() {
        running = false;
        if (!out.started)
            return;
        timeout = setTimeout(run, msGap);
    }
    const out = {
        started: false,
        start() {
            out.started = true;
            if (!running && timeout == null)
                run();
        },
        stop() {
            out.started = false;
            if (timeout != null) {
                clearTimeout(timeout);
                timeout = undefined;
            }
        }
    };
    return out;
}
