/**
 * Interprets an array of 0-4 numbers as a web CSS sides shorthand
 * (top, right, bottom, left).
 */
export function fixSides(sides, fallback) {
    var _a, _b, _c, _d;
    if (sides == null) {
        return [fallback, fallback, fallback, fallback];
    }
    if (typeof sides === 'number') {
        return [sides, sides, sides, sides];
    }
    const top = (_a = sides[0]) !== null && _a !== void 0 ? _a : fallback;
    const right = (_b = sides[1]) !== null && _b !== void 0 ? _b : top;
    const bottom = (_c = sides[2]) !== null && _c !== void 0 ? _c : top;
    const left = (_d = sides[3]) !== null && _d !== void 0 ? _d : right;
    return [top, right, bottom, left];
}
export function mapSides(sides, f) {
    return [f(sides[0]), f(sides[1]), f(sides[2]), f(sides[3])];
}
/**
 * Turns a list of sides into CSS margin properties.
 */
export function sidesToMargin(sides) {
    return {
        marginTop: sides[0],
        marginRight: sides[1],
        marginBottom: sides[2],
        marginLeft: sides[3]
    };
}
/**
 * Turns a list of sides into CSS padding properties.
 */
export function sidesToPadding(sides) {
    return {
        paddingTop: sides[0],
        paddingRight: sides[1],
        paddingBottom: sides[2],
        paddingLeft: sides[3]
    };
}
